@@ -1,12 +1,12 @@
 #!/usr/bin/env python
-# pylint: disable=C0116,W0613
+# pylint: disable=unused-argument
 # This program is dedicated to the public domain under the CC0 license.
 
 """Simple inline keyboard bot with multiple CallbackQueryHandlers.
 
-This Bot uses the Updater class to handle the bot.
+This Bot uses the Application class to handle the bot.
 First, a few callback functions are defined as callback query handler. Then, those functions are
-passed to the Dispatcher and registered at their respective places.
+passed to the Application and registered at their respective places.
 Then, the bot is started and runs until we press Ctrl-C on the command line.
 Usage:
 Example of a bot that uses inline keyboard that has multiple CallbackQueryHandlers arranged in a
@@ -15,29 +15,32 @@ Send /start to initiate the conversation.
 Press Ctrl-C on the command line to stop the bot.
 """
 import logging
+
 from telegram import InlineKeyboardButton, InlineKeyboardMarkup, Update
 from telegram.ext import (
-    Updater,
-    CommandHandler,
+    Application,
     CallbackQueryHandler,
+    CommandHandler,
+    ContextTypes,
     ConversationHandler,
-    CallbackContext,
 )
 
 # Enable logging
 logging.basicConfig(
-    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s', level=logging.INFO
+    format="%(asctime)s - %(name)s - %(levelname)s - %(message)s", level=logging.INFO
 )
+# set higher logging level for httpx to avoid all GET and POST requests being logged
+logging.getLogger("httpx").setLevel(logging.WARNING)
 
 logger = logging.getLogger(__name__)
 
 # Stages
-FIRST, SECOND = range(2)
+START_ROUTES, END_ROUTES = range(2)
 # Callback data
 ONE, TWO, THREE, FOUR = range(4)
 
 
-def start(update: Update, context: CallbackContext) -> int:
+async def start(update: Update, context: ContextTypes.DEFAULT_TYPE) -> int:
     """Send message on `/start`."""
     # Get user that sent /start and log his name
     user = update.message.from_user
@@ -54,18 +57,18 @@ def start(update: Update, context: CallbackContext) -> int:
     ]
     reply_markup = InlineKeyboardMarkup(keyboard)
     # Send message with text and appended InlineKeyboard
-    update.message.reply_text("Start handler, Choose a route", reply_markup=reply_markup)
+    await update.message.reply_text("Start handler, Choose a route", reply_markup=reply_markup)
     # Tell ConversationHandler that we're in state `FIRST` now
-    return FIRST
+    return START_ROUTES
 
 
-def start_over(update: Update, context: CallbackContext) -> int:
+async def start_over(update: Update, context: ContextTypes.DEFAULT_TYPE) -> int:
     """Prompt same text & keyboard as `start` does but not as new message"""
     # Get CallbackQuery from Update
     query = update.callback_query
     # CallbackQueries need to be answered, even if no notification to the user is needed
     # Some clients may have trouble otherwise. See https://core.telegram.org/bots/api#callbackquery
-    query.answer()
+    await query.answer()
     keyboard = [
         [
             InlineKeyboardButton("1", callback_data=str(ONE)),
@@ -76,14 +79,14 @@ def start_over(update: Update, context: CallbackContext) -> int:
     # Instead of sending a new message, edit the message that
     # originated the CallbackQuery. This gives the feeling of an
     # interactive menu.
-    query.edit_message_text(text="Start handler, Choose a route", reply_markup=reply_markup)
-    return FIRST
+    await query.edit_message_text(text="Start handler, Choose a route", reply_markup=reply_markup)
+    return START_ROUTES
 
 
-def one(update: Update, context: CallbackContext) -> int:
+async def one(update: Update, context: ContextTypes.DEFAULT_TYPE) -> int:
     """Show new choice of buttons"""
     query = update.callback_query
-    query.answer()
+    await query.answer()
     keyboard = [
         [
             InlineKeyboardButton("3", callback_data=str(THREE)),
@@ -91,16 +94,16 @@ def one(update: Update, context: CallbackContext) -> int:
         ]
     ]
     reply_markup = InlineKeyboardMarkup(keyboard)
-    query.edit_message_text(
+    await query.edit_message_text(
         text="First CallbackQueryHandler, Choose a route", reply_markup=reply_markup
     )
-    return FIRST
+    return START_ROUTES
 
 
-def two(update: Update, context: CallbackContext) -> int:
+async def two(update: Update, context: ContextTypes.DEFAULT_TYPE) -> int:
     """Show new choice of buttons"""
     query = update.callback_query
-    query.answer()
+    await query.answer()
     keyboard = [
         [
             InlineKeyboardButton("1", callback_data=str(ONE)),
@@ -108,16 +111,16 @@ def two(update: Update, context: CallbackContext) -> int:
         ]
     ]
     reply_markup = InlineKeyboardMarkup(keyboard)
-    query.edit_message_text(
+    await query.edit_message_text(
         text="Second CallbackQueryHandler, Choose a route", reply_markup=reply_markup
     )
-    return FIRST
+    return START_ROUTES
 
 
-def three(update: Update, context: CallbackContext) -> int:
-    """Show new choice of buttons"""
+async def three(update: Update, context: ContextTypes.DEFAULT_TYPE) -> int:
+    """Show new choice of buttons. This is the end point of the conversation."""
     query = update.callback_query
-    query.answer()
+    await query.answer()
     keyboard = [
         [
             InlineKeyboardButton("Yes, let's do it again!", callback_data=str(ONE)),
@@ -125,17 +128,17 @@ def three(update: Update, context: CallbackContext) -> int:
         ]
     ]
     reply_markup = InlineKeyboardMarkup(keyboard)
-    query.edit_message_text(
+    await query.edit_message_text(
         text="Third CallbackQueryHandler. Do want to start over?", reply_markup=reply_markup
     )
     # Transfer to conversation state `SECOND`
-    return SECOND
+    return END_ROUTES
 
 
-def four(update: Update, context: CallbackContext) -> int:
+async def four(update: Update, context: ContextTypes.DEFAULT_TYPE) -> int:
     """Show new choice of buttons"""
     query = update.callback_query
-    query.answer()
+    await query.answer()
     keyboard = [
         [
             InlineKeyboardButton("2", callback_data=str(TWO)),
@@ -143,29 +146,26 @@ def four(update: Update, context: CallbackContext) -> int:
         ]
     ]
     reply_markup = InlineKeyboardMarkup(keyboard)
-    query.edit_message_text(
+    await query.edit_message_text(
         text="Fourth CallbackQueryHandler, Choose a route", reply_markup=reply_markup
     )
-    return FIRST
+    return START_ROUTES
 
 
-def end(update: Update, context: CallbackContext) -> int:
+async def end(update: Update, context: ContextTypes.DEFAULT_TYPE) -> int:
     """Returns `ConversationHandler.END`, which tells the
     ConversationHandler that the conversation is over.
     """
     query = update.callback_query
-    query.answer()
-    query.edit_message_text(text="See you next time!")
+    await query.answer()
+    await query.edit_message_text(text="See you next time!")
     return ConversationHandler.END
 
 
 def main() -> None:
     """Run the bot."""
-    # Create the Updater and pass it your bot's token.
-    updater = Updater("TOKEN")
-
-    # Get the dispatcher to register handlers
-    dispatcher = updater.dispatcher
+    # Create the Application and pass it your bot's token.
+    application = Application.builder().token("TOKEN").build()
 
     # Setup conversation handler with the states FIRST and SECOND
     # Use the pattern parameter to pass CallbackQueries with specific
@@ -174,33 +174,28 @@ def main() -> None:
     # $ means "end of line/string"
     # So ^ABC$ will only allow 'ABC'
     conv_handler = ConversationHandler(
-        entry_points=[CommandHandler('start', start)],
+        entry_points=[CommandHandler("start", start)],
         states={
-            FIRST: [
-                CallbackQueryHandler(one, pattern='^' + str(ONE) + '$'),
-                CallbackQueryHandler(two, pattern='^' + str(TWO) + '$'),
-                CallbackQueryHandler(three, pattern='^' + str(THREE) + '$'),
-                CallbackQueryHandler(four, pattern='^' + str(FOUR) + '$'),
+            START_ROUTES: [
+                CallbackQueryHandler(one, pattern="^" + str(ONE) + "$"),
+                CallbackQueryHandler(two, pattern="^" + str(TWO) + "$"),
+                CallbackQueryHandler(three, pattern="^" + str(THREE) + "$"),
+                CallbackQueryHandler(four, pattern="^" + str(FOUR) + "$"),
             ],
-            SECOND: [
-                CallbackQueryHandler(start_over, pattern='^' + str(ONE) + '$'),
-                CallbackQueryHandler(end, pattern='^' + str(TWO) + '$'),
+            END_ROUTES: [
+                CallbackQueryHandler(start_over, pattern="^" + str(ONE) + "$"),
+                CallbackQueryHandler(end, pattern="^" + str(TWO) + "$"),
             ],
         },
-        fallbacks=[CommandHandler('start', start)],
+        fallbacks=[CommandHandler("start", start)],
     )
 
-    # Add ConversationHandler to dispatcher that will be used for handling updates
-    dispatcher.add_handler(conv_handler)
+    # Add ConversationHandler to application that will be used for handling updates
+    application.add_handler(conv_handler)
 
-    # Start the Bot
-    updater.start_polling()
-
-    # Run the bot until you press Ctrl-C or the process receives SIGINT,
-    # SIGTERM or SIGABRT. This should be used most of the time, since
-    # start_polling() is non-blocking and will stop the bot gracefully.
-    updater.idle()
+    # Run the bot until the user presses Ctrl-C
+    application.run_polling(allowed_updates=Update.ALL_TYPES)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
