@@ -47,9 +47,9 @@ async def msg(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
     # Files will be downloaded to current directory
     for data in passport_data.decrypted_data:  # This is where the data gets decrypted
         if data.type == "phone_number":
-            print("Phone: ", data.phone_number)
+            logger.info("Phone: %s", data.phone_number)
         elif data.type == "email":
-            print("Email: ", data.email)
+            logger.info("Email: %s", data.email)
         if data.type in (
             "personal_details",
             "passport",
@@ -58,7 +58,7 @@ async def msg(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
             "internal_passport",
             "address",
         ):
-            print(data.type, data.data)
+            logger.info(data.type, data.data)
         if data.type in (
             "utility_bill",
             "bank_statement",
@@ -66,28 +66,28 @@ async def msg(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
             "passport_registration",
             "temporary_registration",
         ):
-            print(data.type, len(data.files), "files")
+            logger.info(data.type, len(data.files), "files")
             for file in data.files:
                 actual_file = await file.get_file()
-                print(actual_file)
+                logger.info(actual_file)
                 await actual_file.download_to_drive()
         if (
             data.type in ("passport", "driver_license", "identity_card", "internal_passport")
             and data.front_side
         ):
             front_file = await data.front_side.get_file()
-            print(data.type, front_file)
+            logger.info(data.type, front_file)
             await front_file.download_to_drive()
         if data.type in ("driver_license" and "identity_card") and data.reverse_side:
             reverse_file = await data.reverse_side.get_file()
-            print(data.type, reverse_file)
+            logger.info(data.type, reverse_file)
             await reverse_file.download_to_drive()
         if (
             data.type in ("passport", "driver_license", "identity_card", "internal_passport")
             and data.selfie
         ):
             selfie_file = await data.selfie.get_file()
-            print(data.type, selfie_file)
+            logger.info(data.type, selfie_file)
             await selfie_file.download_to_drive()
         if data.translation and data.type in (
             "passport",
@@ -100,10 +100,10 @@ async def msg(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
             "passport_registration",
             "temporary_registration",
         ):
-            print(data.type, len(data.translation), "translation")
+            logger.info(data.type, len(data.translation), "translation")
             for file in data.translation:
                 actual_file = await file.get_file()
-                print(actual_file)
+                logger.info(actual_file)
                 await actual_file.download_to_drive()
 
 
