@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains a class that represents a Telegram InputInvoiceMessageContent."""
-from typing import TYPE_CHECKING, Optional, Sequence, Tuple
+from collections.abc import Sequence
+from typing import TYPE_CHECKING, Optional
 
 from telegram._inline.inputmessagecontent import InputMessageContent
 from telegram._payment.labeledprice import LabeledPrice
@@ -47,7 +48,7 @@ class InputInvoiceMessageContent(InputMessageContent):
         payload (:obj:`str`): Bot-defined invoice payload.
             :tg-const:`telegram.Invoice.MIN_PAYLOAD_LENGTH`-
             :tg-const:`telegram.Invoice.MAX_PAYLOAD_LENGTH` bytes. This will not be displayed
-            to the user, use for your internal processes.
+            to the user, use it for your internal processes.
         provider_token (:obj:`str`): Payment provider token, obtained via
             `@Botfather <https://t.me/Botfather>`_. Pass an empty string for payments in
             |tg_stars|.
@@ -66,14 +67,13 @@ class InputInvoiceMessageContent(InputMessageContent):
                 |sequenceclassargs|
 
         max_tip_amount (:obj:`int`, optional): The maximum accepted amount for tips in the
-            *smallest* units of the currency (integer, **not** float/double). For example, for a
-            maximum tip of US$ 1.45 pass ``max_tip_amount = 145``. See the ``exp`` parameter in
+            *smallest units* of the currency (integer, **not** float/double). For example, for a
+            maximum tip of ``US$ 1.45`` pass ``max_tip_amount = 145``. See the ``exp`` parameter in
             `currencies.json <https://core.telegram.org/bots/payments/currencies.json>`_, it
             shows the number of digits past the decimal point for each currency (2 for the majority
-            of currencies). Defaults to ``0``. Defaults to ``0``. Not supported for payments in
-            |tg_stars|.
+            of currencies). Defaults to ``0``. Not supported for payments in |tg_stars|.
         suggested_tip_amounts (Sequence[:obj:`int`], optional): An array of suggested
-            amounts of tip in the *smallest* units of the currency (integer, **not** float/double).
+            amounts of tip in the *smallest units* of the currency (integer, **not** float/double).
             At most 4 suggested tip amounts can be specified. The suggested tip amounts must be
             positive, passed in a strictly increased order and must not exceed
             :attr:`max_tip_amount`.
@@ -116,14 +116,14 @@ class InputInvoiceMessageContent(InputMessageContent):
         payload (:obj:`str`): Bot-defined invoice payload.
             :tg-const:`telegram.Invoice.MIN_PAYLOAD_LENGTH`-
             :tg-const:`telegram.Invoice.MAX_PAYLOAD_LENGTH` bytes. This will not be displayed
-            to the user, use for your internal processes.
+            to the user, use it for your internal processes.
         provider_token (:obj:`str`): Payment provider token, obtained via
             `@Botfather <https://t.me/Botfather>`_. Pass an empty string for payments in `Telegram
             Stars <https://t.me/BotNews/90>`_.
         currency (:obj:`str`): Three-letter ISO 4217 currency code, see more on
             `currencies <https://core.telegram.org/bots/payments#supported-currencies>`_.
             Pass ``XTR`` for payments in |tg_stars|.
-        prices (Tuple[:class:`telegram.LabeledPrice`]): Price breakdown, a list of
+        prices (tuple[:class:`telegram.LabeledPrice`]): Price breakdown, a list of
             components (e.g. product price, tax, discount, delivery cost, delivery tax, bonus,
             etc.). Must contain exactly one item for payments in |tg_stars|.
 
@@ -131,13 +131,13 @@ class InputInvoiceMessageContent(InputMessageContent):
                 |tupleclassattrs|
 
         max_tip_amount (:obj:`int`): Optional. The maximum accepted amount for tips in the
-            *smallest* units of the currency (integer, **not** float/double). For example, for a
-            maximum tip of US$ 1.45 ``max_tip_amount`` is ``145``. See the ``exp`` parameter in
+            *smallest units* of the currency (integer, **not** float/double). For example, for a
+            maximum tip of ``US$ 1.45`` ``max_tip_amount`` is ``145``. See the ``exp`` parameter in
             `currencies.json <https://core.telegram.org/bots/payments/currencies.json>`_, it
             shows the number of digits past the decimal point for each currency (2 for the majority
             of currencies). Defaults to ``0``. Not supported for payments in |tg_stars|.
-        suggested_tip_amounts (Tuple[:obj:`int`]): Optional. An array of suggested
-            amounts of tip in the *smallest* units of the currency (integer, **not** float/double).
+        suggested_tip_amounts (tuple[:obj:`int`]): Optional. An array of suggested
+            amounts of tip in the *smallest units* of the currency (integer, **not** float/double).
             At most 4 suggested tip amounts can be specified. The suggested tip amounts must be
             positive, passed in a strictly increased order and must not exceed
             :attr:`max_tip_amount`.
@@ -227,10 +227,10 @@ class InputInvoiceMessageContent(InputMessageContent):
             self.payload: str = payload
             self.provider_token: Optional[str] = provider_token
             self.currency: str = currency
-            self.prices: Tuple[LabeledPrice, ...] = parse_sequence_arg(prices)
+            self.prices: tuple[LabeledPrice, ...] = parse_sequence_arg(prices)
             # Optionals
             self.max_tip_amount: Optional[int] = max_tip_amount
-            self.suggested_tip_amounts: Tuple[int, ...] = parse_sequence_arg(suggested_tip_amounts)
+            self.suggested_tip_amounts: tuple[int, ...] = parse_sequence_arg(suggested_tip_amounts)
             self.provider_data: Optional[str] = provider_data
             self.photo_url: Optional[str] = photo_url
             self.photo_size: Optional[int] = photo_size
@@ -255,7 +255,7 @@ class InputInvoiceMessageContent(InputMessageContent):
 
     @classmethod
     def de_json(
-        cls, data: Optional[JSONDict], bot: "Bot"
+        cls, data: Optional[JSONDict], bot: Optional["Bot"] = None
     ) -> Optional["InputInvoiceMessageContent"]:
         """See :meth:`telegram.TelegramObject.de_json`."""
         data = cls._parse_data(data)
