@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an object that represents a Encrypted PassportFile."""
 
-from typing import TYPE_CHECKING, List, Optional, Tuple
+from typing import TYPE_CHECKING, Optional
 
 from telegram._telegramobject import TelegramObject
 from telegram._utils.defaultvalue import DEFAULT_NONE
@@ -107,23 +107,32 @@ class PassportFile(TelegramObject):
             This attribute will return a datetime instead of a integer in future major versions.
         """
         warn(
-            "The attribute `file_date` will return a datetime instead of an integer in future"
-            " major versions.",
-            PTBDeprecationWarning,
+            PTBDeprecationWarning(
+                "20.6",
+                "The attribute `file_date` will return a datetime instead of an integer in future"
+                " major versions.",
+            ),
             stacklevel=2,
         )
         return self._file_date
 
     @classmethod
     def de_json_decrypted(
-        cls, data: Optional[JSONDict], bot: "Bot", credentials: "FileCredentials"
+        cls, data: Optional[JSONDict], bot: Optional["Bot"], credentials: "FileCredentials"
     ) -> Optional["PassportFile"]:
         """Variant of :meth:`telegram.TelegramObject.de_json` that also takes into account
         passport credentials.
 
         Args:
-            data (Dict[:obj:`str`, ...]): The JSON data.
-            bot (:class:`telegram.Bot`): The bot associated with this object.
+            data (dict[:obj:`str`, ...]): The JSON data.
+            bot (:class:`telegram.Bot` | :obj:`None`): The bot associated with these object.
+                May be :obj:`None`, in which case shortcut methods will not be available.
+
+                .. versionchanged:: 21.4
+                   :paramref:`bot` is now optional and defaults to :obj:`None`
+
+                .. deprecated:: 21.4
+                   This argument will be converted to an optional argument in future versions.
             credentials (:class:`telegram.FileCredentials`): The credentials
 
         Returns:
@@ -141,8 +150,11 @@ class PassportFile(TelegramObject):
 
     @classmethod
     def de_list_decrypted(
-        cls, data: Optional[List[JSONDict]], bot: "Bot", credentials: List["FileCredentials"]
-    ) -> Tuple[Optional["PassportFile"], ...]:
+        cls,
+        data: Optional[list[JSONDict]],
+        bot: Optional["Bot"],
+        credentials: list["FileCredentials"],
+    ) -> tuple[Optional["PassportFile"], ...]:
         """Variant of :meth:`telegram.TelegramObject.de_list` that also takes into account
         passport credentials.
 
@@ -152,12 +164,19 @@ class PassportFile(TelegramObject):
            * Filters out any :obj:`None` values
 
         Args:
-            data (List[Dict[:obj:`str`, ...]]): The JSON data.
-            bot (:class:`telegram.Bot`): The bot associated with these objects.
+            data (list[dict[:obj:`str`, ...]]): The JSON data.
+            bot (:class:`telegram.Bot` | :obj:`None`): The bot associated with these object.
+                May be :obj:`None`, in which case shortcut methods will not be available.
+
+                .. versionchanged:: 21.4
+                   :paramref:`bot` is now optional and defaults to :obj:`None`
+
+                .. deprecated:: 21.4
+                   This argument will be converted to an optional argument in future versions.
             credentials (:class:`telegram.FileCredentials`): The credentials
 
         Returns:
-            Tuple[:class:`telegram.PassportFile`]:
+            tuple[:class:`telegram.PassportFile`]:
 
         """
         if not data:
@@ -184,7 +203,7 @@ class PassportFile(TelegramObject):
         """
         Wrapper over :meth:`telegram.Bot.get_file`. Will automatically assign the correct
         credentials to the returned :class:`telegram.File` if originating from
-        :obj:`telegram.PassportData.decrypted_data`.
+        :attr:`telegram.PassportData.decrypted_data`.
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.get_file`.
 
