@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -42,14 +42,15 @@ class PreCheckoutQuery(TelegramObject):
     Args:
         id (:obj:`str`): Unique query identifier.
         from_user (:class:`telegram.User`): User who sent the query.
-        currency (:obj:`str`): Three-letter ISO 4217 currency code.
-        total_amount (:obj:`int`): Total price in the smallest units of the currency (integer, not
-            float/double). For example, for a price of US$ 1.45 pass ``amount = 145``.
+        currency (:obj:`str`): Three-letter ISO 4217 currency code, or ``XTR`` for payments in
+            |tg_stars|.
+        total_amount (:obj:`int`): Total price in the smallest units of the currency (integer,
+            **not** float/double). For example, for a price of ``US$ 1.45`` pass ``amount = 145``.
             See the ``exp`` parameter in
             `currencies.json <https://core.telegram.org/bots/payments/currencies.json>`_,
             it shows the number of digits past the decimal point for each currency
             (2 for the majority of currencies).
-        invoice_payload (:obj:`str`): Bot specified invoice payload.
+        invoice_payload (:obj:`str`): Bot-specified invoice payload.
         shipping_option_id (:obj:`str`, optional): Identifier of the shipping option chosen by the
             user.
         order_info (:class:`telegram.OrderInfo`, optional): Order info provided by the user.
@@ -57,14 +58,15 @@ class PreCheckoutQuery(TelegramObject):
     Attributes:
         id (:obj:`str`): Unique query identifier.
         from_user (:class:`telegram.User`): User who sent the query.
-        currency (:obj:`str`): Three-letter ISO 4217 currency code.
-        total_amount (:obj:`int`): Total price in the smallest units of the currency (integer, not
-            float/double). For example, for a price of US$ 1.45 ``amount`` is ``145``.
+        currency (:obj:`str`): Three-letter ISO 4217 currency code, or ``XTR`` for payments in
+            |tg_stars|.
+        total_amount (:obj:`int`): Total price in the smallest units of the currency (integer,
+            **not** float/double). For example, for a price of ``US$ 1.45`` pass ``amount = 145``.
             See the ``exp`` parameter in
             `currencies.json <https://core.telegram.org/bots/payments/currencies.json>`_,
             it shows the number of digits past the decimal point for each currency
             (2 for the majority of currencies).
-        invoice_payload (:obj:`str`): Bot specified invoice payload.
+        invoice_payload (:obj:`str`): Bot-specified invoice payload.
         shipping_option_id (:obj:`str`): Optional. Identifier of the shipping option chosen by the
             user.
         order_info (:class:`telegram.OrderInfo`): Optional. Order info provided by the user.
@@ -108,7 +110,9 @@ class PreCheckoutQuery(TelegramObject):
         self._freeze()
 
     @classmethod
-    def de_json(cls, data: Optional[JSONDict], bot: "Bot") -> Optional["PreCheckoutQuery"]:
+    def de_json(
+        cls, data: Optional[JSONDict], bot: Optional["Bot"] = None
+    ) -> Optional["PreCheckoutQuery"]:
         """See :meth:`telegram.TelegramObject.de_json`."""
         data = cls._parse_data(data)
 
