@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -17,8 +17,9 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an object that represents a Telegram Poll."""
-import datetime
-from typing import TYPE_CHECKING, Dict, Final, List, Optional, Sequence, Tuple
+import datetime as dtm
+from collections.abc import Sequence
+from typing import TYPE_CHECKING, Final, Optional
 
 from telegram import constants
 from telegram._chat import Chat
@@ -28,12 +29,82 @@ from telegram._user import User
 from telegram._utils import enum
 from telegram._utils.argumentparsing import parse_sequence_arg
 from telegram._utils.datetime import extract_tzinfo_from_defaults, from_timestamp
-from telegram._utils.types import JSONDict
+from telegram._utils.defaultvalue import DEFAULT_NONE
+from telegram._utils.entities import parse_message_entities, parse_message_entity
+from telegram._utils.types import JSONDict, ODVInput
 
 if TYPE_CHECKING:
     from telegram import Bot
 
 
+class InputPollOption(TelegramObject):
+    """
+    This object contains information about one answer option in a poll to be sent.
+
+    Objects of this class are comparable in terms of equality. Two objects of this class are
+    considered equal, if their :attr:`text` is equal.
+
+    .. versionadded:: 21.2
+
+    Args:
+        text (:obj:`str`): Option text,
+            :tg-const:`telegram.PollOption.MIN_LENGTH`-:tg-const:`telegram.PollOption.MAX_LENGTH`
+            characters.
+        text_parse_mode (:obj:`str`, optional): |parse_mode|
+            Currently, only custom emoji entities are allowed.
+        text_entities (Sequence[:class:`telegram.MessageEntity`], optional): Special entities
+            that appear in the option :paramref:`text`. It can be specified instead of
+            :paramref:`text_parse_mode`.
+            Currently, only custom emoji entities are allowed.
+            This list is empty if the text does not contain entities.
+
+    Attributes:
+        text (:obj:`str`): Option text,
+            :tg-const:`telegram.PollOption.MIN_LENGTH`-:tg-const:`telegram.PollOption.MAX_LENGTH`
+            characters.
+        text_parse_mode (:obj:`str`): Optional. |parse_mode|
+            Currently, only custom emoji entities are allowed.
+        text_entities (Sequence[:class:`telegram.MessageEntity`]): Special entities
+            that appear in the option :paramref:`text`. It can be specified instead of
+            :paramref:`text_parse_mode`.
+            Currently, only custom emoji entities are allowed.
+            This list is empty if the text does not contain entities.
+    """
+
+    __slots__ = ("text", "text_entities", "text_parse_mode")
+
+    def __init__(
+        self,
+        text: str,
+        text_parse_mode: ODVInput[str] = DEFAULT_NONE,
+        text_entities: Optional[Sequence[MessageEntity]] = None,
+        *,
+        api_kwargs: Optional[JSONDict] = None,
+    ):
+        super().__init__(api_kwargs=api_kwargs)
+        self.text: str = text
+        self.text_parse_mode: ODVInput[str] = text_parse_mode
+        self.text_entities: tuple[MessageEntity, ...] = parse_sequence_arg(text_entities)
+
+        self._id_attrs = (self.text,)
+
+        self._freeze()
+
+    @classmethod
+    def de_json(
+        cls, data: Optional[JSONDict], bot: Optional["Bot"] = None
+    ) -> Optional["InputPollOption"]:
+        """See :meth:`telegram.TelegramObject.de_json`."""
+        data = cls._parse_data(data)
+
+        if not data:
+            return None
+
+        data["text_entities"] = MessageEntity.de_list(data.get("text_entities"), bot)
+
+        return super().de_json(data=data, bot=bot)
+
+
 class PollOption(TelegramObject):
     """
     This object contains information about one answer option in a poll.
@@ -46,26 +117,103 @@ class PollOption(TelegramObject):
             :tg-const:`telegram.PollOption.MIN_LENGTH`-:tg-const:`telegram.PollOption.MAX_LENGTH`
             characters.
         voter_count (:obj:`int`): Number of users that voted for this option.
+        text_entities (Sequence[:class:`telegram.MessageEntity`], optional): Special entities
+            that appear in the option text. Currently, only custom emoji entities are allowed in
+            poll option texts.
+
+            .. versionadded:: 21.2
 
     Attributes:
         text (:obj:`str`): Option text,
             :tg-const:`telegram.PollOption.MIN_LENGTH`-:tg-const:`telegram.PollOption.MAX_LENGTH`
             characters.
         voter_count (:obj:`int`): Number of users that voted for this option.
+        text_entities (tuple[:class:`telegram.MessageEntity`]): Special entities
+            that appear in the option text. Currently, only custom emoji entities are allowed in
+            poll option texts.
+            This list is empty if the question does not contain entities.
+
+            .. versionadded:: 21.2
 
     """
 
-    __slots__ = ("text", "voter_count")
+    __slots__ = ("text", "text_entities", "voter_count")
 
-    def __init__(self, text: str, voter_count: int, *, api_kwargs: Optional[JSONDict] = None):
+    def __init__(
+        self,
+        text: str,
+        voter_count: int,
+        text_entities: Optional[Sequence[MessageEntity]] = None,
+        *,
+        api_kwargs: Optional[JSONDict] = None,
+    ):
         super().__init__(api_kwargs=api_kwargs)
         self.text: str = text
         self.voter_count: int = voter_count
+        self.text_entities: tuple[MessageEntity, ...] = parse_sequence_arg(text_entities)
 
         self._id_attrs = (self.text, self.voter_count)
 
         self._freeze()
 
+    @classmethod
+    def de_json(
+        cls, data: Optional[JSONDict], bot: Optional["Bot"] = None
+    ) -> Optional["PollOption"]:
+        """See :meth:`telegram.TelegramObject.de_json`."""
+        data = cls._parse_data(data)
+
+        if not data:
+            return None
+
+        data["text_entities"] = MessageEntity.de_list(data.get("text_entities"), bot)
+
+        return super().de_json(data=data, bot=bot)
+
+    def parse_entity(self, entity: MessageEntity) -> str:
+        """Returns the text in :attr:`text`
+        from a given :class:`telegram.MessageEntity` of :attr:`text_entities`.
+
+        Note:
+            This method is present because Telegram calculates the offset and length in
+            UTF-16 codepoint pairs, which some versions of Python don't handle automatically.
+            (That is, you can't just slice ``Message.text`` with the offset and length.)
+
+        .. versionadded:: 21.2
+
+        Args:
+            entity (:class:`telegram.MessageEntity`): The entity to extract the text from. It must
+                be an entity that belongs to :attr:`text_entities`.
+
+        Returns:
+            :obj:`str`: The text of the given entity.
+        """
+        return parse_message_entity(self.text, entity)
+
+    def parse_entities(self, types: Optional[list[str]] = None) -> dict[MessageEntity, str]:
+        """
+        Returns a :obj:`dict` that maps :class:`telegram.MessageEntity` to :obj:`str`.
+        It contains entities from this polls question filtered by their ``type`` attribute as
+        the key, and the text that each entity belongs to as the value of the :obj:`dict`.
+
+        Note:
+            This method should always be used instead of the :attr:`text_entities`
+            attribute, since it calculates the correct substring from the message text based on
+            UTF-16 codepoints. See :attr:`parse_entity` for more info.
+
+        .. versionadded:: 21.2
+
+        Args:
+            types (list[:obj:`str`], optional): List of ``MessageEntity`` types as strings. If the
+                    ``type`` attribute of an entity is contained in this list, it will be returned.
+                    Defaults to :attr:`telegram.MessageEntity.ALL_TYPES`.
+
+        Returns:
+            dict[:class:`telegram.MessageEntity`, :obj:`str`]: A dictionary of entities mapped to
+            the text that belongs to them, calculated based on UTF-16 codepoints.
+        """
+        return parse_message_entities(self.text, self.text_entities, types)
+
     MIN_LENGTH: Final[int] = constants.PollLimit.MIN_OPTION_LENGTH
     """:const:`telegram.constants.PollLimit.MIN_OPTION_LENGTH`
 
@@ -113,7 +261,7 @@ class PollAnswer(TelegramObject):
 
     Attributes:
         poll_id (:obj:`str`): Unique poll identifier.
-        option_ids (Tuple[:obj:`int`]): Identifiers of answer options, chosen by the user. May
+        option_ids (tuple[:obj:`int`]): Identifiers of answer options, chosen by the user. May
             be empty if the user retracted their vote.
 
             .. versionchanged:: 20.0
@@ -145,7 +293,7 @@ class PollAnswer(TelegramObject):
         super().__init__(api_kwargs=api_kwargs)
         self.poll_id: str = poll_id
         self.voter_chat: Optional[Chat] = voter_chat
-        self.option_ids: Tuple[int, ...] = parse_sequence_arg(option_ids)
+        self.option_ids: tuple[int, ...] = parse_sequence_arg(option_ids)
         self.user: Optional[User] = user
 
         self._id_attrs = (
@@ -158,7 +306,9 @@ class PollAnswer(TelegramObject):
         self._freeze()
 
     @classmethod
-    def de_json(cls, data: Optional[JSONDict], bot: "Bot") -> Optional["PollAnswer"]:
+    def de_json(
+        cls, data: Optional[JSONDict], bot: Optional["Bot"] = None
+    ) -> Optional["PollAnswer"]:
         """See :meth:`telegram.TelegramObject.de_json`."""
         data = cls._parse_data(data)
 
@@ -215,12 +365,17 @@ class Poll(TelegramObject):
 
             .. versionchanged:: 20.3
                 |datetime_localization|
+        question_entities (Sequence[:class:`telegram.MessageEntity`], optional): Special entities
+            that appear in the :attr:`question`. Currently, only custom emoji entities are allowed
+            in poll questions.
+
+            .. versionadded:: 21.2
 
     Attributes:
         id (:obj:`str`): Unique poll identifier.
         question (:obj:`str`): Poll question, :tg-const:`telegram.Poll.MIN_QUESTION_LENGTH`-
             :tg-const:`telegram.Poll.MAX_QUESTION_LENGTH` characters.
-        options (Tuple[:class:`~telegram.PollOption`]): List of poll options.
+        options (tuple[:class:`~telegram.PollOption`]): List of poll options.
 
             .. versionchanged:: 20.0
                 |tupleclassattrs|
@@ -235,7 +390,7 @@ class Poll(TelegramObject):
         explanation (:obj:`str`): Optional. Text that is shown when a user chooses an incorrect
             answer or taps on the lamp icon in a quiz-style poll,
             0-:tg-const:`telegram.Poll.MAX_EXPLANATION_LENGTH` characters.
-        explanation_entities (Tuple[:class:`telegram.MessageEntity`]): Special entities
+        explanation_entities (tuple[:class:`telegram.MessageEntity`]): Special entities
             like usernames, URLs, bot commands, etc. that appear in the :attr:`explanation`.
             This list is empty if the message does not contain explanation entities.
 
@@ -251,6 +406,12 @@ class Poll(TelegramObject):
 
             .. versionchanged:: 20.3
                 |datetime_localization|
+        question_entities (tuple[:class:`telegram.MessageEntity`]): Special entities
+            that appear in the :attr:`question`. Currently, only custom emoji entities are allowed
+            in poll questions.
+            This list is empty if the question does not contain entities.
+
+            .. versionadded:: 21.2
 
     """
 
@@ -266,6 +427,7 @@ class Poll(TelegramObject):
         "open_period",
         "options",
         "question",
+        "question_entities",
         "total_voter_count",
         "type",
     )
@@ -284,14 +446,15 @@ class Poll(TelegramObject):
         explanation: Optional[str] = None,
         explanation_entities: Optional[Sequence[MessageEntity]] = None,
         open_period: Optional[int] = None,
-        close_date: Optional[datetime.datetime] = None,
+        close_date: Optional[dtm.datetime] = None,
+        question_entities: Optional[Sequence[MessageEntity]] = None,
         *,
         api_kwargs: Optional[JSONDict] = None,
     ):
         super().__init__(api_kwargs=api_kwargs)
         self.id: str = id
         self.question: str = question
-        self.options: Tuple[PollOption, ...] = parse_sequence_arg(options)
+        self.options: tuple[PollOption, ...] = parse_sequence_arg(options)
         self.total_voter_count: int = total_voter_count
         self.is_closed: bool = is_closed
         self.is_anonymous: bool = is_anonymous
@@ -299,18 +462,19 @@ class Poll(TelegramObject):
         self.allows_multiple_answers: bool = allows_multiple_answers
         self.correct_option_id: Optional[int] = correct_option_id
         self.explanation: Optional[str] = explanation
-        self.explanation_entities: Tuple[MessageEntity, ...] = parse_sequence_arg(
+        self.explanation_entities: tuple[MessageEntity, ...] = parse_sequence_arg(
             explanation_entities
         )
         self.open_period: Optional[int] = open_period
-        self.close_date: Optional[datetime.datetime] = close_date
+        self.close_date: Optional[dtm.datetime] = close_date
+        self.question_entities: tuple[MessageEntity, ...] = parse_sequence_arg(question_entities)
 
         self._id_attrs = (self.id,)
 
         self._freeze()
 
     @classmethod
-    def de_json(cls, data: Optional[JSONDict], bot: "Bot") -> Optional["Poll"]:
+    def de_json(cls, data: Optional[JSONDict], bot: Optional["Bot"] = None) -> Optional["Poll"]:
         """See :meth:`telegram.TelegramObject.de_json`."""
         data = cls._parse_data(data)
 
@@ -323,11 +487,13 @@ class Poll(TelegramObject):
         data["options"] = [PollOption.de_json(option, bot) for option in data["options"]]
         data["explanation_entities"] = MessageEntity.de_list(data.get("explanation_entities"), bot)
         data["close_date"] = from_timestamp(data.get("close_date"), tzinfo=loc_tzinfo)
+        data["question_entities"] = MessageEntity.de_list(data.get("question_entities"), bot)
 
         return super().de_json(data=data, bot=bot)
 
     def parse_explanation_entity(self, entity: MessageEntity) -> str:
-        """Returns the text from a given :class:`telegram.MessageEntity`.
+        """Returns the text in :attr:`explanation` from a given :class:`telegram.MessageEntity` of
+        :attr:`explanation_entities`.
 
         Note:
             This method is present because Telegram calculates the offset and length in
@@ -336,7 +502,7 @@ class Poll(TelegramObject):
 
         Args:
             entity (:class:`telegram.MessageEntity`): The entity to extract the text from. It must
-                be an entity that belongs to this message.
+                be an entity that belongs to :attr:`explanation_entities`.
 
         Returns:
             :obj:`str`: The text of the given entity.
@@ -348,14 +514,11 @@ class Poll(TelegramObject):
         if not self.explanation:
             raise RuntimeError("This Poll has no 'explanation'.")
 
-        entity_text = self.explanation.encode("utf-16-le")
-        entity_text = entity_text[entity.offset * 2 : (entity.offset + entity.length) * 2]
-
-        return entity_text.decode("utf-16-le")
+        return parse_message_entity(self.explanation, entity)
 
     def parse_explanation_entities(
-        self, types: Optional[List[str]] = None
-    ) -> Dict[MessageEntity, str]:
+        self, types: Optional[list[str]] = None
+    ) -> dict[MessageEntity, str]:
         """
         Returns a :obj:`dict` that maps :class:`telegram.MessageEntity` to :obj:`str`.
         It contains entities from this polls explanation filtered by their ``type`` attribute as
@@ -367,23 +530,69 @@ class Poll(TelegramObject):
             UTF-16 codepoints. See :attr:`parse_explanation_entity` for more info.
 
         Args:
-            types (List[:obj:`str`], optional): List of ``MessageEntity`` types as strings. If the
+            types (list[:obj:`str`], optional): List of ``MessageEntity`` types as strings. If the
                     ``type`` attribute of an entity is contained in this list, it will be returned.
                     Defaults to :attr:`telegram.MessageEntity.ALL_TYPES`.
 
         Returns:
-            Dict[:class:`telegram.MessageEntity`, :obj:`str`]: A dictionary of entities mapped to
+            dict[:class:`telegram.MessageEntity`, :obj:`str`]: A dictionary of entities mapped to
+            the text that belongs to them, calculated based on UTF-16 codepoints.
+
+        Raises:
+            RuntimeError: If the poll has no explanation.
+
+        """
+        if not self.explanation:
+            raise RuntimeError("This Poll has no 'explanation'.")
+
+        return parse_message_entities(self.explanation, self.explanation_entities, types)
+
+    def parse_question_entity(self, entity: MessageEntity) -> str:
+        """Returns the text in :attr:`question` from a given :class:`telegram.MessageEntity` of
+        :attr:`question_entities`.
+
+        .. versionadded:: 21.2
+
+        Note:
+            This method is present because Telegram calculates the offset and length in
+            UTF-16 codepoint pairs, which some versions of Python don't handle automatically.
+            (That is, you can't just slice ``Message.text`` with the offset and length.)
+
+        Args:
+            entity (:class:`telegram.MessageEntity`): The entity to extract the text from. It must
+                be an entity that belongs to :attr:`question_entities`.
+
+        Returns:
+            :obj:`str`: The text of the given entity.
+        """
+        return parse_message_entity(self.question, entity)
+
+    def parse_question_entities(
+        self, types: Optional[list[str]] = None
+    ) -> dict[MessageEntity, str]:
+        """
+        Returns a :obj:`dict` that maps :class:`telegram.MessageEntity` to :obj:`str`.
+        It contains entities from this polls question filtered by their ``type`` attribute as
+        the key, and the text that each entity belongs to as the value of the :obj:`dict`.
+
+        .. versionadded:: 21.2
+
+        Note:
+            This method should always be used instead of the :attr:`question_entities`
+            attribute, since it calculates the correct substring from the message text based on
+            UTF-16 codepoints. See :attr:`parse_question_entity` for more info.
+
+        Args:
+            types (list[:obj:`str`], optional): List of ``MessageEntity`` types as strings. If the
+                    ``type`` attribute of an entity is contained in this list, it will be returned.
+                    Defaults to :attr:`telegram.MessageEntity.ALL_TYPES`.
+
+        Returns:
+            dict[:class:`telegram.MessageEntity`, :obj:`str`]: A dictionary of entities mapped to
             the text that belongs to them, calculated based on UTF-16 codepoints.
 
         """
-        if types is None:
-            types = MessageEntity.ALL_TYPES
-
-        return {
-            entity: self.parse_explanation_entity(entity)
-            for entity in self.explanation_entities
-            if entity.type in types
-        }
+        return parse_message_entities(self.question, self.question_entities, types)
 
     REGULAR: Final[str] = constants.PollType.REGULAR
     """:const:`telegram.constants.PollType.REGULAR`"""
