@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This modules contains objects that represents Telegram Replies"""
-from typing import TYPE_CHECKING, Optional, Sequence, Tuple, Union
+from collections.abc import Sequence
+from typing import TYPE_CHECKING, Optional, Union
 
 from telegram._chat import Chat
 from telegram._dice import Dice
@@ -92,14 +93,13 @@ class ExternalReplyInfo(TelegramObject):
             about the contact.
         dice (:class:`telegram.Dice`, optional): Message is a dice with random value.
         game (:Class:`telegram.Game`. optional): Message is a game, information about the game.
-            `More about games >> <https://core.telegram.org/bots/api#games>`_.
+            :ref:`More about games >> <games-tree>`.
         giveaway (:class:`telegram.Giveaway`, optional): Message is a scheduled giveaway,
             information about the giveaway.
         giveaway_winners (:class:`telegram.GiveawayWinners`, optional): A giveaway with public
             winners was completed.
         invoice (:class:`telegram.Invoice`, optional): Message is an invoice for a payment,
-            information about the invoice. `More about payments >>
-            <https://core.telegram.org/bots/api#payments>`_.
+            information about the invoice. :ref:`More about payments >> <payments-tree>`.
         location (:class:`telegram.Location`, optional): Message is a shared location, information
             about the location.
         poll (:class:`telegram.Poll`, optional): Message is a native poll, information about the
@@ -125,7 +125,7 @@ class ExternalReplyInfo(TelegramObject):
             file.
         document (:class:`telegram.Document`): Optional. Message is a general file, information
             about the file.
-        photo (Tuple[:class:`telegram.PhotoSize`]): Optional. Message is a photo, available sizes
+        photo (tuple[:class:`telegram.PhotoSize`]): Optional. Message is a photo, available sizes
             of the photo.
         sticker (:class:`telegram.Sticker`): Optional. Message is a sticker, information about the
             sticker.
@@ -142,14 +142,13 @@ class ExternalReplyInfo(TelegramObject):
             about the contact.
         dice (:class:`telegram.Dice`): Optional. Message is a dice with random value.
         game (:Class:`telegram.Game`): Optional. Message is a game, information about the game.
-            `More about games >> <https://core.telegram.org/bots/api#games>`_.
+            :ref:`More about games >> <games-tree>`.
         giveaway (:class:`telegram.Giveaway`): Optional. Message is a scheduled giveaway,
             information about the giveaway.
         giveaway_winners (:class:`telegram.GiveawayWinners`): Optional. A giveaway with public
             winners was completed.
         invoice (:class:`telegram.Invoice`): Optional. Message is an invoice for a payment,
-            information about the invoice. `More about payments >>
-            <https://core.telegram.org/bots/api#payments>`_.
+            information about the invoice. :ref:`More about payments >> <payments-tree>`.
         location (:class:`telegram.Location`): Optional. Message is a shared location, information
             about the location.
         poll (:class:`telegram.Poll`): Optional. Message is a native poll, information about the
@@ -226,7 +225,7 @@ class ExternalReplyInfo(TelegramObject):
         self.animation: Optional[Animation] = animation
         self.audio: Optional[Audio] = audio
         self.document: Optional[Document] = document
-        self.photo: Optional[Tuple[PhotoSize, ...]] = parse_sequence_arg(photo)
+        self.photo: Optional[tuple[PhotoSize, ...]] = parse_sequence_arg(photo)
         self.sticker: Optional[Sticker] = sticker
         self.story: Optional[Story] = story
         self.video: Optional[Video] = video
@@ -252,7 +251,7 @@ class ExternalReplyInfo(TelegramObject):
     def de_json(
         cls, data: Optional[JSONDict], bot: Optional["Bot"] = None
     ) -> Optional["ExternalReplyInfo"]:
-        """See :obj:`telegram.TelegramObject.de_json`."""
+        """See :meth:`telegram.TelegramObject.de_json`."""
         data = cls._parse_data(data)
 
         if data is None:
@@ -301,7 +300,8 @@ class TextQuote(TelegramObject):
             message.
         position (:obj:`int`): Approximate quote position in the original message in UTF-16 code
             units as specified by the sender.
-        entities (Sequence[:obj:`telegram.MessageEntity`], optional): Special entities that appear
+        entities (Sequence[:class:`telegram.MessageEntity`], optional): Special entities that
+            appear
             in the quote. Currently, only bold, italic, underline, strikethrough, spoiler, and
             custom_emoji entities are kept in quotes.
         is_manual (:obj:`bool`, optional): :obj:`True`, if the quote was chosen manually by the
@@ -312,7 +312,7 @@ class TextQuote(TelegramObject):
             message.
         position (:obj:`int`): Approximate quote position in the original message in UTF-16 code
             units as specified by the sender.
-        entities (Tuple[:obj:`telegram.MessageEntity`]): Optional. Special entities that appear
+        entities (tuple[:class:`telegram.MessageEntity`]): Optional. Special entities that appear
             in the quote. Currently, only bold, italic, underline, strikethrough, spoiler, and
             custom_emoji entities are kept in quotes.
         is_manual (:obj:`bool`): Optional. :obj:`True`, if the quote was chosen manually by the
@@ -339,7 +339,7 @@ class TextQuote(TelegramObject):
 
         self.text: str = text
         self.position: int = position
-        self.entities: Optional[Tuple[MessageEntity, ...]] = parse_sequence_arg(entities)
+        self.entities: Optional[tuple[MessageEntity, ...]] = parse_sequence_arg(entities)
         self.is_manual: Optional[bool] = is_manual
 
         self._id_attrs = (
@@ -353,7 +353,7 @@ class TextQuote(TelegramObject):
     def de_json(
         cls, data: Optional[JSONDict], bot: Optional["Bot"] = None
     ) -> Optional["TextQuote"]:
-        """See :obj:`telegram.TelegramObject.de_json`."""
+        """See :meth:`telegram.TelegramObject.de_json`."""
         data = cls._parse_data(data)
 
         if data is None:
@@ -389,7 +389,8 @@ class ReplyParameters(TelegramObject):
         quote_parse_mode (:obj:`str`, optional): Mode for parsing entities in the quote. See
             :wiki:`formatting options <Code-snippets#message-formatting-bold-italic-code->` for
             more details.
-        quote_entities (Sequence[:obj:`telegram.MessageEntity`], optional): A JSON-serialized list
+        quote_entities (Sequence[:class:`telegram.MessageEntity`], optional): A JSON-serialized
+            list
             of special entities that appear in the quote. It can be specified instead of
             :paramref:`quote_parse_mode`.
         quote_position (:obj:`int`, optional): Position of the quote in the original message in
@@ -411,8 +412,8 @@ class ReplyParameters(TelegramObject):
         quote_parse_mode (:obj:`str`): Optional. Mode for parsing entities in the quote. See
             :wiki:`formatting options <Code-snippets#message-formatting-bold-italic-code->` for
             more details.
-        quote_entities (Tuple[:obj:`telegram.MessageEntity`]): Optional. A JSON-serialized list of
-            special entities that appear in the quote. It can be specified instead of
+        quote_entities (tuple[:class:`telegram.MessageEntity`]): Optional. A JSON-serialized list
+            of special entities that appear in the quote. It can be specified instead of
             :paramref:`quote_parse_mode`.
         quote_position (:obj:`int`): Optional. Position of the quote in the original message in
             UTF-16 code units.
@@ -447,7 +448,7 @@ class ReplyParameters(TelegramObject):
         self.allow_sending_without_reply: ODVInput[bool] = allow_sending_without_reply
         self.quote: Optional[str] = quote
         self.quote_parse_mode: ODVInput[str] = quote_parse_mode
-        self.quote_entities: Optional[Tuple[MessageEntity, ...]] = parse_sequence_arg(
+        self.quote_entities: Optional[tuple[MessageEntity, ...]] = parse_sequence_arg(
             quote_entities
         )
         self.quote_position: Optional[int] = quote_position
@@ -460,7 +461,7 @@ class ReplyParameters(TelegramObject):
     def de_json(
         cls, data: Optional[JSONDict], bot: Optional["Bot"] = None
     ) -> Optional["ReplyParameters"]:
-        """See :obj:`telegram.TelegramObject.de_json`."""
+        """See :meth:`telegram.TelegramObject.de_json`."""
         data = cls._parse_data(data)
 
         if data is None:
