@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -29,7 +29,7 @@ Warning:
 """
 
 from pathlib import Path
-from typing import IO, TYPE_CHECKING, Any, Optional, Tuple, Type, TypeVar, Union, cast, overload
+from typing import IO, TYPE_CHECKING, Any, Optional, TypeVar, Union, cast, overload
 
 from telegram._utils.types import FileInput, FilePathInput
 
@@ -40,16 +40,16 @@ _T = TypeVar("_T", bound=Union[bytes, "InputFile", str, Path, None])
 
 
 @overload
-def load_file(obj: IO[bytes]) -> Tuple[Optional[str], bytes]: ...
+def load_file(obj: IO[bytes]) -> tuple[Optional[str], bytes]: ...
 
 
 @overload
-def load_file(obj: _T) -> Tuple[None, _T]: ...
+def load_file(obj: _T) -> tuple[None, _T]: ...
 
 
 def load_file(
     obj: Optional[FileInput],
-) -> Tuple[Optional[str], Union[bytes, "InputFile", str, Path, None]]:
+) -> tuple[Optional[str], Union[bytes, "InputFile", str, Path, None]]:
     """If the input is a file handle, read the data and name and return it. Otherwise, return
     the input unchanged.
     """
@@ -61,14 +61,21 @@ def load_file(
     except AttributeError:
         return None, cast(Union[bytes, "InputFile", str, Path], obj)
 
-    if hasattr(obj, "name") and not isinstance(obj.name, int):
-        filename = Path(obj.name).name
-    else:
-        filename = None
+    filename = guess_file_name(obj)
 
     return filename, contents
 
 
+def guess_file_name(obj: FileInput) -> Optional[str]:
+    """If the input is a file handle, read name and return it. Otherwise, return
+    the input unchanged.
+    """
+    if hasattr(obj, "name") and not isinstance(obj.name, int):
+        return Path(obj.name).name
+
+    return None
+
+
 def is_local_file(obj: Optional[FilePathInput]) -> bool:
     """
     Checks if a given string is a file on local system.
@@ -88,7 +95,7 @@ def is_local_file(obj: Optional[FilePathInput]) -> bool:
 
 def parse_file_input(  # pylint: disable=too-many-return-statements
     file_input: Union[FileInput, "TelegramObject"],
-    tg_type: Optional[Type["TelegramObject"]] = None,
+    tg_type: Optional[type["TelegramObject"]] = None,
     filename: Optional[str] = None,
     attach: bool = False,
     local_mode: bool = False,
@@ -110,8 +117,8 @@ def parse_file_input(  # pylint: disable=too-many-return-statements
       attribute.
 
     Args:
-        file_input (:obj:`str` | :obj:`bytes` | :term:`file object` | Telegram media object): The
-            input to parse.
+        file_input (:obj:`str` | :obj:`bytes` | :term:`file object` | :class:`~telegram.InputFile`\
+            | Telegram media object): The input to parse.
         tg_type (:obj:`type`, optional): The Telegram media type the input can be. E.g.
             :class:`telegram.Animation`.
         filename (:obj:`str`, optional): The filename. Only relevant in case an
