@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -36,20 +36,7 @@ __all__ = (
     "TimedOut",
 )
 
-from typing import Optional, Tuple, Union
-
-
-def _lstrip_str(in_s: str, lstr: str) -> str:
-    """
-    Args:
-        in_s (:obj:`str`): in string
-        lstr (:obj:`str`): substr to strip from left side
-
-    Returns:
-        :obj:`str`: The stripped string.
-
-    """
-    return in_s[len(lstr) :] if in_s.startswith(lstr) else in_s
+from typing import Optional, Union
 
 
 class TelegramError(Exception):
@@ -70,9 +57,9 @@ class TelegramError(Exception):
     def __init__(self, message: str):
         super().__init__()
 
-        msg = _lstrip_str(message, "Error: ")
-        msg = _lstrip_str(msg, "[Error]: ")
-        msg = _lstrip_str(msg, "Bad Request: ")
+        msg = message.removeprefix("Error: ")
+        msg = msg.removeprefix("[Error]: ")
+        msg = msg.removeprefix("Bad Request: ")
         if msg != message:
             # api_error - capitalize the msg...
             msg = msg.capitalize()
@@ -94,7 +81,7 @@ class TelegramError(Exception):
         """
         return f"{self.__class__.__name__}('{self.message}')"
 
-    def __reduce__(self) -> Tuple[type, Tuple[str]]:
+    def __reduce__(self) -> tuple[type, tuple[str]]:
         """Defines how to serialize the exception for pickle.
 
         .. seealso::
@@ -209,7 +196,7 @@ class ChatMigrated(TelegramError):
         super().__init__(f"Group migrated to supergroup. New chat id: {new_chat_id}")
         self.new_chat_id: int = new_chat_id
 
-    def __reduce__(self) -> Tuple[type, Tuple[int]]:  # type: ignore[override]
+    def __reduce__(self) -> tuple[type, tuple[int]]:  # type: ignore[override]
         return self.__class__, (self.new_chat_id,)
 
 
@@ -234,7 +221,7 @@ class RetryAfter(TelegramError):
         super().__init__(f"Flood control exceeded. Retry in {retry_after} seconds")
         self.retry_after: int = retry_after
 
-    def __reduce__(self) -> Tuple[type, Tuple[float]]:  # type: ignore[override]
+    def __reduce__(self) -> tuple[type, tuple[float]]:  # type: ignore[override]
         return self.__class__, (self.retry_after,)
 
 
@@ -243,7 +230,7 @@ class Conflict(TelegramError):
 
     __slots__ = ()
 
-    def __reduce__(self) -> Tuple[type, Tuple[str]]:
+    def __reduce__(self) -> tuple[type, tuple[str]]:
         return self.__class__, (self.message,)
 
 
@@ -261,5 +248,5 @@ class PassportDecryptionError(TelegramError):
         super().__init__(f"PassportDecryptionError: {message}")
         self._msg = str(message)
 
-    def __reduce__(self) -> Tuple[type, Tuple[str]]:
+    def __reduce__(self) -> tuple[type, tuple[str]]:
         return self.__class__, (self._msg,)
