@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -19,13 +19,15 @@
 """This module contains an abstract class to make POST and GET requests."""
 import abc
 import json
+from contextlib import AbstractAsyncContextManager
 from http import HTTPStatus
 from types import TracebackType
-from typing import AsyncContextManager, Final, List, Optional, Tuple, Type, TypeVar, Union, final
+from typing import Final, Optional, TypeVar, Union, final
 
 from telegram._utils.defaultvalue import DEFAULT_NONE as _DEFAULT_NONE
 from telegram._utils.defaultvalue import DefaultValue
 from telegram._utils.logging import get_logger
+from telegram._utils.strings import TextEncoding
 from telegram._utils.types import JSONDict, ODVInput
 from telegram._utils.warnings import warn
 from telegram._version import __version__ as ptb_ver
@@ -48,7 +50,7 @@ _LOGGER = get_logger(__name__, class_name="BaseRequest")
 
 
 class BaseRequest(
-    AsyncContextManager["BaseRequest"],
+    AbstractAsyncContextManager["BaseRequest"],
     abc.ABC,
 ):
     """Abstract interface class that allows python-telegram-bot to make requests to the Bot API.
@@ -114,14 +116,14 @@ class BaseRequest(
         """
         try:
             await self.initialize()
-            return self
-        except Exception as exc:
+        except Exception:
             await self.shutdown()
-            raise exc
+            raise
+        return self
 
     async def __aexit__(
         self,
-        exc_type: Optional[Type[BaseException]],
+        exc_type: Optional[type[BaseException]],
         exc_val: Optional[BaseException],
         exc_tb: Optional[TracebackType],
     ) -> None:
@@ -165,7 +167,7 @@ class BaseRequest(
         write_timeout: ODVInput[float] = DEFAULT_NONE,
         connect_timeout: ODVInput[float] = DEFAULT_NONE,
         pool_timeout: ODVInput[float] = DEFAULT_NONE,
-    ) -> Union[JSONDict, List[JSONDict], bool]:
+    ) -> Union[JSONDict, list[JSONDict], bool]:
         """Makes a request to the Bot API handles the return code and parses the answer.
 
         Warning:
@@ -318,10 +320,12 @@ class BaseRequest(
             and isinstance(write_timeout, DefaultValue)
         ):
             warn(
-                f"The `write_timeout` parameter passed to {self.__class__.__name__}.do_request "
-                "will default to `BaseRequest.DEFAULT_NONE` instead of 20 in future versions "
-                "for *all* methods of the `Bot` class, including methods sending media.",
-                PTBDeprecationWarning,
+                PTBDeprecationWarning(
+                    "20.7",
+                    f"The `write_timeout` parameter passed to {self.__class__.__name__}.do_request"
+                    " will default to `BaseRequest.DEFAULT_NONE` instead of 20 in future versions "
+                    "for *all* methods of the `Bot` class, including methods sending media.",
+                ),
                 stacklevel=3,
             )
             write_timeout = 20
@@ -336,8 +340,8 @@ class BaseRequest(
                 connect_timeout=connect_timeout,
                 pool_timeout=pool_timeout,
             )
-        except TelegramError as exc:
-            raise exc
+        except TelegramError:
+            raise
         except Exception as exc:
             raise NetworkError(f"Unknown error in HTTP implementation: {exc!r}") from exc
 
@@ -401,11 +405,11 @@ class BaseRequest(
         Raises:
             TelegramError: If loading the JSON data failed
         """
-        decoded_s = payload.decode("utf-8", "replace")
+        decoded_s = payload.decode(TextEncoding.UTF_8, "replace")
         try:
             return json.loads(decoded_s)
         except ValueError as exc:
-            _LOGGER.error('Can not load invalid JSON data: "%s"', decoded_s)
+            _LOGGER.exception('Can not load invalid JSON data: "%s"', decoded_s)
             raise TelegramError("Invalid server response") from exc
 
     @abc.abstractmethod
@@ -418,7 +422,7 @@ class BaseRequest(
         write_timeout: ODVInput[float] = DEFAULT_NONE,
         connect_timeout: ODVInput[float] = DEFAULT_NONE,
         pool_timeout: ODVInput[float] = DEFAULT_NONE,
-    ) -> Tuple[int, bytes]:
+    ) -> tuple[int, bytes]:
         """Makes a request to the Bot API. Must be implemented by a subclass.
 
         Warning:
@@ -448,6 +452,6 @@ class BaseRequest(
                 :attr:`DEFAULT_NONE`.
 
         Returns:
-            Tuple[:obj:`int`, :obj:`bytes`]: The HTTP return code & the payload part of the server
+            tuple[:obj:`int`, :obj:`bytes`]: The HTTP return code & the payload part of the server
             response.
         """
