@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -36,7 +36,7 @@ from tests.auxil.networking import expect_bad_request
 from tests.auxil.slots import mro_slots
 
 
-@pytest.fixture()
+@pytest.fixture
 def chatphoto_file():
     with data_file("telegram.jpg").open("rb") as f:
         yield f
@@ -52,7 +52,7 @@ async def chat_photo(bot, super_group_id):
     )
 
 
-class TestChatPhotoBase:
+class ChatPhotoTestBase:
     chatphoto_small_file_id = "smallCgADAQADngIAAuyVeEez0xRovKi9VAI"
     chatphoto_big_file_id = "bigCgADAQADngIAAuyVeEez0xRovKi9VAI"
     chatphoto_small_file_unique_id = "smalladc3145fd2e84d95b64d68eaa22aa33e"
@@ -60,20 +60,20 @@ class TestChatPhotoBase:
     chatphoto_file_url = "https://python-telegram-bot.org/static/testfiles/telegram.jpg"
 
 
-class TestChatPhotoWithoutRequest(TestChatPhotoBase):
+class TestChatPhotoWithoutRequest(ChatPhotoTestBase):
     def test_slot_behaviour(self, chat_photo):
         for attr in chat_photo.__slots__:
             assert getattr(chat_photo, attr, "err") != "err", f"got extra slot '{attr}'"
         assert len(mro_slots(chat_photo)) == len(set(mro_slots(chat_photo))), "duplicate slot"
 
-    def test_de_json(self, bot, chat_photo):
+    def test_de_json(self, offline_bot, chat_photo):
         json_dict = {
             "small_file_id": self.chatphoto_small_file_id,
             "big_file_id": self.chatphoto_big_file_id,
             "small_file_unique_id": self.chatphoto_small_file_unique_id,
             "big_file_unique_id": self.chatphoto_big_file_unique_id,
         }
-        chat_photo = ChatPhoto.de_json(json_dict, bot)
+        chat_photo = ChatPhoto.de_json(json_dict, offline_bot)
         assert chat_photo.api_kwargs == {}
         assert chat_photo.small_file_id == self.chatphoto_small_file_id
         assert chat_photo.big_file_id == self.chatphoto_big_file_id
@@ -121,12 +121,14 @@ class TestChatPhotoWithoutRequest(TestChatPhotoBase):
         assert a != e
         assert hash(a) != hash(e)
 
-    async def test_send_with_chat_photo(self, monkeypatch, bot, super_group_id, chat_photo):
+    async def test_send_with_chat_photo(
+        self, monkeypatch, offline_bot, super_group_id, chat_photo
+    ):
         async def make_assertion(url, request_data: RequestData, *args, **kwargs):
             return request_data.parameters["photo"] == chat_photo.to_dict()
 
-        monkeypatch.setattr(bot.request, "post", make_assertion)
-        message = await bot.set_chat_photo(photo=chat_photo, chat_id=super_group_id)
+        monkeypatch.setattr(offline_bot.request, "post", make_assertion)
+        message = await offline_bot.set_chat_photo(photo=chat_photo, chat_id=super_group_id)
         assert message
 
     async def test_get_small_file_instance_method(self, monkeypatch, chat_photo):
