@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@ import pytest
 
 from telegram import (
     CallbackGame,
+    CopyTextButton,
     InlineKeyboardButton,
     LoginUrl,
     SwitchInlineQueryChosenChat,
@@ -32,24 +33,25 @@ from tests.auxil.slots import mro_slots
 @pytest.fixture(scope="module")
 def inline_keyboard_button():
     return InlineKeyboardButton(
-        TestInlineKeyboardButtonBase.text,
-        url=TestInlineKeyboardButtonBase.url,
-        callback_data=TestInlineKeyboardButtonBase.callback_data,
-        switch_inline_query=TestInlineKeyboardButtonBase.switch_inline_query,
+        InlineKeyboardButtonTestBase.text,
+        url=InlineKeyboardButtonTestBase.url,
+        callback_data=InlineKeyboardButtonTestBase.callback_data,
+        switch_inline_query=InlineKeyboardButtonTestBase.switch_inline_query,
         switch_inline_query_current_chat=(
-            TestInlineKeyboardButtonBase.switch_inline_query_current_chat
+            InlineKeyboardButtonTestBase.switch_inline_query_current_chat
         ),
-        callback_game=TestInlineKeyboardButtonBase.callback_game,
-        pay=TestInlineKeyboardButtonBase.pay,
-        login_url=TestInlineKeyboardButtonBase.login_url,
-        web_app=TestInlineKeyboardButtonBase.web_app,
+        callback_game=InlineKeyboardButtonTestBase.callback_game,
+        pay=InlineKeyboardButtonTestBase.pay,
+        login_url=InlineKeyboardButtonTestBase.login_url,
+        web_app=InlineKeyboardButtonTestBase.web_app,
         switch_inline_query_chosen_chat=(
-            TestInlineKeyboardButtonBase.switch_inline_query_chosen_chat
+            InlineKeyboardButtonTestBase.switch_inline_query_chosen_chat
         ),
+        copy_text=InlineKeyboardButtonTestBase.copy_text,
     )
 
 
-class TestInlineKeyboardButtonBase:
+class InlineKeyboardButtonTestBase:
     text = "text"
     url = "url"
     callback_data = "callback data"
@@ -60,9 +62,10 @@ class TestInlineKeyboardButtonBase:
     login_url = LoginUrl("http://google.com")
     web_app = WebAppInfo(url="https://example.com")
     switch_inline_query_chosen_chat = SwitchInlineQueryChosenChat("a_bot", True, False, True, True)
+    copy_text = CopyTextButton("python-telegram-bot")
 
 
-class TestInlineKeyboardButtonWithoutRequest(TestInlineKeyboardButtonBase):
+class TestInlineKeyboardButtonWithoutRequest(InlineKeyboardButtonTestBase):
     def test_slot_behaviour(self, inline_keyboard_button):
         inst = inline_keyboard_button
         for attr in inst.__slots__:
@@ -86,6 +89,7 @@ class TestInlineKeyboardButtonWithoutRequest(TestInlineKeyboardButtonBase):
             inline_keyboard_button.switch_inline_query_chosen_chat
             == self.switch_inline_query_chosen_chat
         )
+        assert inline_keyboard_button.copy_text == self.copy_text
 
     def test_to_dict(self, inline_keyboard_button):
         inline_keyboard_button_dict = inline_keyboard_button.to_dict()
@@ -115,8 +119,11 @@ class TestInlineKeyboardButtonWithoutRequest(TestInlineKeyboardButtonBase):
             inline_keyboard_button_dict["switch_inline_query_chosen_chat"]
             == inline_keyboard_button.switch_inline_query_chosen_chat.to_dict()
         )
+        assert (
+            inline_keyboard_button_dict["copy_text"] == inline_keyboard_button.copy_text.to_dict()
+        )
 
-    def test_de_json(self, bot):
+    def test_de_json(self, offline_bot):
         json_dict = {
             "text": self.text,
             "url": self.url,
@@ -128,6 +135,7 @@ class TestInlineKeyboardButtonWithoutRequest(TestInlineKeyboardButtonBase):
             "login_url": self.login_url.to_dict(),
             "pay": self.pay,
             "switch_inline_query_chosen_chat": self.switch_inline_query_chosen_chat.to_dict(),
+            "copy_text": self.copy_text.to_dict(),
         }
 
         inline_keyboard_button = InlineKeyboardButton.de_json(json_dict, None)
@@ -149,8 +157,9 @@ class TestInlineKeyboardButtonWithoutRequest(TestInlineKeyboardButtonBase):
             inline_keyboard_button.switch_inline_query_chosen_chat
             == self.switch_inline_query_chosen_chat
         )
+        assert inline_keyboard_button.copy_text == self.copy_text
 
-        none = InlineKeyboardButton.de_json({}, bot)
+        none = InlineKeyboardButton.de_json({}, offline_bot)
         assert none is None
 
     def test_equality(self):
