@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -25,19 +25,19 @@ from tests.auxil.slots import mro_slots
 @pytest.fixture(scope="module")
 def input_contact_message_content():
     return InputContactMessageContent(
-        TestInputContactMessageContentBase.phone_number,
-        TestInputContactMessageContentBase.first_name,
-        TestInputContactMessageContentBase.last_name,
+        InputContactMessageContentTestBase.phone_number,
+        InputContactMessageContentTestBase.first_name,
+        InputContactMessageContentTestBase.last_name,
     )
 
 
-class TestInputContactMessageContentBase:
+class InputContactMessageContentTestBase:
     phone_number = "phone number"
     first_name = "first name"
     last_name = "last name"
 
 
-class TestInputContactMessageContentWithoutRequest(TestInputContactMessageContentBase):
+class TestInputContactMessageContentWithoutRequest(InputContactMessageContentTestBase):
     def test_slot_behaviour(self, input_contact_message_content):
         inst = input_contact_message_content
         for attr in inst.__slots__:
