@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -26,13 +26,13 @@ from tests.auxil.slots import mro_slots
 @pytest.fixture(scope="module")
 def passport_element_error_translation_files():
     return PassportElementErrorTranslationFiles(
-        TestPassportElementErrorTranslationFilesBase.type_,
-        TestPassportElementErrorTranslationFilesBase.file_hashes,
-        TestPassportElementErrorTranslationFilesBase.message,
+        PassportElementErrorTranslationFilesTestBase.type_,
+        PassportElementErrorTranslationFilesTestBase.file_hashes,
+        PassportElementErrorTranslationFilesTestBase.message,
     )
 
 
-class TestPassportElementErrorTranslationFilesBase:
+class PassportElementErrorTranslationFilesTestBase:
     source = "translation_files"
     type_ = "test_type"
     file_hashes = ["hash1", "hash2"]
@@ -40,7 +40,7 @@ class TestPassportElementErrorTranslationFilesBase:
 
 
 class TestPassportElementErrorTranslationFilesWithoutRequest(
-    TestPassportElementErrorTranslationFilesBase
+    PassportElementErrorTranslationFilesTestBase
 ):
     def test_slot_behaviour(self, passport_element_error_translation_files):
         inst = passport_element_error_translation_files
