@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -60,6 +60,7 @@ from telegram.warnings import PTBDeprecationWarning, PTBUserWarning
 from tests.auxil.asyncio_helpers import call_after
 from tests.auxil.build_messages import make_message_update
 from tests.auxil.files import PROJECT_ROOT_PATH
+from tests.auxil.monkeypatch import empty_get_updates, return_true
 from tests.auxil.networking import send_webhook_message
 from tests.auxil.pytest_classes import PytestApplication, PytestUpdater, make_bot
 from tests.auxil.slots import mro_slots
@@ -301,15 +302,19 @@ class TestApplication:
         )
 
         if updater:
-            async with ApplicationBuilder().bot(one_time_bot).concurrent_updates(
-                update_processor
-            ).build():
+            async with (
+                ApplicationBuilder().bot(one_time_bot).concurrent_updates(update_processor).build()
+            ):
                 pass
             assert self.test_flag == {"bot", "update_processor", "updater"}
         else:
-            async with ApplicationBuilder().bot(one_time_bot).updater(None).concurrent_updates(
-                update_processor
-            ).build():
+            async with (
+                ApplicationBuilder()
+                .bot(one_time_bot)
+                .updater(None)
+                .concurrent_updates(update_processor)
+                .build()
+            ):
                 pass
             assert self.test_flag == {"bot", "update_processor"}
 
@@ -432,7 +437,7 @@ class TestApplication:
 
     @pytest.mark.parametrize("job_queue", [True, False])
     @pytest.mark.filterwarnings("ignore::telegram.warnings.PTBUserWarning")
-    async def test_start_stop_processing_updates(self, one_time_bot, job_queue):
+    async def test_start_stop_processing_updates(self, one_time_bot, job_queue, monkeypatch):
         # TODO: repeat a similar test for create_task, persistence processing and job queue
         if job_queue:
             app = ApplicationBuilder().bot(one_time_bot).build()
@@ -442,6 +447,9 @@ class TestApplication:
         async def callback(u, c):
             self.received = u
 
+        monkeypatch.setattr(app.bot, "get_updates", empty_get_updates)
+        monkeypatch.setattr(app.bot, "delete_webhook", return_true)
+
         assert not app.running
         assert not app.updater.running
         if job_queue:
@@ -639,11 +647,11 @@ class TestApplication:
             assert len(app.handlers[-1]) == 1
 
             # Now lets test the errors which can be produced-
-            with pytest.raises(ValueError, match="The `group` argument"):
+            with pytest.raises(TypeError, match="The `group` argument"):
                 app.add_handlers({2: [msg_handler_set_count]}, group=0)
-            with pytest.raises(ValueError, match="Handlers for group 3"):
+            with pytest.raises(TypeError, match="Handlers for group 3"):
                 app.add_handlers({3: msg_handler_set_count})
-            with pytest.raises(ValueError, match="The `handlers` argument must be a sequence"):
+            with pytest.raises(TypeError, match="The `handlers` argument must be a sequence"):
                 app.add_handlers({msg_handler_set_count})
 
             await app.stop()
@@ -1519,11 +1527,6 @@ class TestApplication:
     def test_run_polling_timeout_deprecation_warnings(
         self, timeout_name, monkeypatch, recwarn, app
     ):
-        async def get_updates(*args, **kwargs):
-            # This makes sure that other coroutines have a chance of running as well
-            await asyncio.sleep(0)
-            return []
-
         def thread_target():
             waited = 0
             while not app.running:
@@ -1536,7 +1539,7 @@ class TestApplication:
 
             os.kill(os.getpid(), signal.SIGINT)
 
-        monkeypatch.setattr(app.bot, "get_updates", get_updates)
+        monkeypatch.setattr(app.bot, "get_updates", empty_get_updates)
 
         thread = Thread(target=thread_target)
         thread.start()
@@ -1563,11 +1566,6 @@ class TestApplication:
     def test_run_polling_post_init(self, one_time_bot, monkeypatch):
         events = []
 
-        async def get_updates(*args, **kwargs):
-            # This makes sure that other coroutines have a chance of running as well
-            await asyncio.sleep(0)
-            return []
-
         def thread_target():
             waited = 0
             while not app.running:
@@ -1589,7 +1587,7 @@ class TestApplication:
             .build()
         )
         app.bot._unfreeze()
-        monkeypatch.setattr(app.bot, "get_updates", get_updates)
+        monkeypatch.setattr(app.bot, "get_updates", empty_get_updates)
         monkeypatch.setattr(
             app, "initialize", call_after(app.initialize, lambda _: events.append("init"))
         )
@@ -1598,6 +1596,7 @@ class TestApplication:
             "start_polling",
             call_after(app.updater.start_polling, lambda _: events.append("start_polling")),
         )
+        monkeypatch.setattr(app.bot, "delete_webhook", return_true)
 
         thread = Thread(target=thread_target)
         thread.start()
@@ -1612,11 +1611,6 @@ class TestApplication:
     def test_run_polling_post_shutdown(self, one_time_bot, monkeypatch):
         events = []
 
-        async def get_updates(*args, **kwargs):
-            # This makes sure that other coroutines have a chance of running as well
-            await asyncio.sleep(0)
-            return []
-
         def thread_target():
             waited = 0
             while not app.running:
@@ -1638,7 +1632,7 @@ class TestApplication:
             .build()
         )
         app.bot._unfreeze()
-        monkeypatch.setattr(app.bot, "get_updates", get_updates)
+        monkeypatch.setattr(app.bot, "get_updates", empty_get_updates)
         monkeypatch.setattr(
             app, "shutdown", call_after(app.shutdown, lambda _: events.append("shutdown"))
         )
@@ -1647,6 +1641,7 @@ class TestApplication:
             "shutdown",
             call_after(app.updater.shutdown, lambda _: events.append("updater.shutdown")),
         )
+        monkeypatch.setattr(app.bot, "delete_webhook", return_true)
 
         thread = Thread(target=thread_target)
         thread.start()
@@ -1665,11 +1660,6 @@ class TestApplication:
     def test_run_polling_post_stop(self, one_time_bot, monkeypatch):
         events = []
 
-        async def get_updates(*args, **kwargs):
-            # This makes sure that other coroutines have a chance of running as well
-            await asyncio.sleep(0)
-            return []
-
         def thread_target():
             waited = 0
             while not app.running:
@@ -1691,7 +1681,7 @@ class TestApplication:
             .build()
         )
         app.bot._unfreeze()
-        monkeypatch.setattr(app.bot, "get_updates", get_updates)
+        monkeypatch.setattr(app.bot, "get_updates", empty_get_updates)
         monkeypatch.setattr(app, "stop", call_after(app.stop, lambda _: events.append("stop")))
         monkeypatch.setattr(
             app.updater,
@@ -1703,6 +1693,7 @@ class TestApplication:
             "shutdown",
             call_after(app.updater.shutdown, lambda _: events.append("updater.shutdown")),
         )
+        monkeypatch.setattr(app.bot, "delete_webhook", return_true)
 
         thread = Thread(target=thread_target)
         thread.start()
@@ -1784,12 +1775,6 @@ class TestApplication:
     def test_run_webhook_basic(self, app, monkeypatch, caplog):
         assertions = {}
 
-        async def delete_webhook(*args, **kwargs):
-            return True
-
-        async def set_webhook(*args, **kwargs):
-            return True
-
         def thread_target():
             waited = 0
             while not app.running:
@@ -1820,8 +1805,6 @@ class TestApplication:
             assertions["updater_not_running"] = not app.updater.running
             assertions["job_queue_not_running"] = not app.job_queue.scheduler.running
 
-        monkeypatch.setattr(app.bot, "set_webhook", set_webhook)
-        monkeypatch.setattr(app.bot, "delete_webhook", delete_webhook)
         app.add_handler(TypeHandler(object, self.callback_set_count(42)))
 
         thread = Thread(target=thread_target)
@@ -1857,17 +1840,6 @@ class TestApplication:
     def test_run_webhook_post_init(self, one_time_bot, monkeypatch):
         events = []
 
-        async def delete_webhook(*args, **kwargs):
-            return True
-
-        async def set_webhook(*args, **kwargs):
-            return True
-
-        async def get_updates(*args, **kwargs):
-            # This makes sure that other coroutines have a chance of running as well
-            await asyncio.sleep(0)
-            return []
-
         def thread_target():
             waited = 0
             while not app.running:
@@ -1889,8 +1861,7 @@ class TestApplication:
             .build()
         )
         app.bot._unfreeze()
-        monkeypatch.setattr(app.bot, "set_webhook", set_webhook)
-        monkeypatch.setattr(app.bot, "delete_webhook", delete_webhook)
+
         monkeypatch.setattr(
             app, "initialize", call_after(app.initialize, lambda _: events.append("init"))
         )
@@ -1899,6 +1870,8 @@ class TestApplication:
             "start_webhook",
             call_after(app.updater.start_webhook, lambda _: events.append("start_webhook")),
         )
+        monkeypatch.setattr(app.bot, "delete_webhook", return_true)
+        monkeypatch.setattr(app.bot, "set_webhook", return_true)
 
         thread = Thread(target=thread_target)
         thread.start()
@@ -1923,17 +1896,6 @@ class TestApplication:
     def test_run_webhook_post_shutdown(self, one_time_bot, monkeypatch):
         events = []
 
-        async def delete_webhook(*args, **kwargs):
-            return True
-
-        async def set_webhook(*args, **kwargs):
-            return True
-
-        async def get_updates(*args, **kwargs):
-            # This makes sure that other coroutines have a chance of running as well
-            await asyncio.sleep(0)
-            return []
-
         def thread_target():
             waited = 0
             while not app.running:
@@ -1955,8 +1917,7 @@ class TestApplication:
             .build()
         )
         app.bot._unfreeze()
-        monkeypatch.setattr(app.bot, "set_webhook", set_webhook)
-        monkeypatch.setattr(app.bot, "delete_webhook", delete_webhook)
+
         monkeypatch.setattr(
             app, "shutdown", call_after(app.shutdown, lambda _: events.append("shutdown"))
         )
@@ -1965,6 +1926,8 @@ class TestApplication:
             "shutdown",
             call_after(app.updater.shutdown, lambda _: events.append("updater.shutdown")),
         )
+        monkeypatch.setattr(app.bot, "delete_webhook", return_true)
+        monkeypatch.setattr(app.bot, "set_webhook", return_true)
 
         thread = Thread(target=thread_target)
         thread.start()
@@ -1993,17 +1956,6 @@ class TestApplication:
     def test_run_webhook_post_stop(self, one_time_bot, monkeypatch):
         events = []
 
-        async def delete_webhook(*args, **kwargs):
-            return True
-
-        async def set_webhook(*args, **kwargs):
-            return True
-
-        async def get_updates(*args, **kwargs):
-            # This makes sure that other coroutines have a chance of running as well
-            await asyncio.sleep(0)
-            return []
-
         def thread_target():
             waited = 0
             while not app.running:
@@ -2025,8 +1977,7 @@ class TestApplication:
             .build()
         )
         app.bot._unfreeze()
-        monkeypatch.setattr(app.bot, "set_webhook", set_webhook)
-        monkeypatch.setattr(app.bot, "delete_webhook", delete_webhook)
+
         monkeypatch.setattr(app, "stop", call_after(app.stop, lambda _: events.append("stop")))
         monkeypatch.setattr(
             app.updater,
@@ -2038,6 +1989,8 @@ class TestApplication:
             "shutdown",
             call_after(app.updater.shutdown, lambda _: events.append("updater.shutdown")),
         )
+        monkeypatch.setattr(app.bot, "delete_webhook", return_true)
+        monkeypatch.setattr(app.bot, "set_webhook", return_true)
 
         thread = Thread(target=thread_target)
         thread.start()
@@ -2217,10 +2170,6 @@ class TestApplication:
         async def callback(*args, **kwargs):
             called_callbacks.add(kwargs["name"])
 
-        async def get_updates(*args, **kwargs):
-            await asyncio.sleep(0)
-            return []
-
         for cls, method, entry in [
             (Application, "initialize", "app_initialize"),
             (Application, "start", "app_start"),
@@ -2249,7 +2198,8 @@ class TestApplication:
             .post_shutdown(functools.partial(callback, name="post_shutdown"))
             .build()
         )
-        monkeypatch.setattr(app.bot, "get_updates", get_updates)
+        monkeypatch.setattr(app.bot, "get_updates", empty_get_updates)
+        monkeypatch.setattr(app.bot, "delete_webhook", return_true)
 
         app.add_handler(TypeHandler(object, update_logger_callback), group=-10)
         app.add_handler(TypeHandler(object, handler_callback))
@@ -2322,6 +2272,9 @@ class TestApplication:
             Updater, "shutdown", call_after(Updater.shutdown, after_shutdown("updater"))
         )
         app = ApplicationBuilder().bot(one_time_bot).build()
+        monkeypatch.setattr(app.bot, "delete_webhook", return_true)
+        monkeypatch.setattr(app.bot, "get_updates", empty_get_updates)
+
         with pytest.raises(RuntimeError, match="Test Exception"):
             app.run_polling(close_loop=False)
 
@@ -2418,7 +2371,9 @@ class TestApplication:
             received_signals.append(args[0])
 
         loop = asyncio.get_event_loop()
+
         monkeypatch.setattr(loop, "add_signal_handler", signal_handler_test)
+        monkeypatch.setattr(app.bot, "get_updates", empty_get_updates)
 
         def abort_app():
             raise SystemExit
@@ -2496,16 +2451,6 @@ class TestApplication:
         called_stop_running = threading.Event()
         assertions = {}
 
-        async def get_updates(*args, **kwargs):
-            await asyncio.sleep(0)
-            return []
-
-        async def delete_webhook(*args, **kwargs):
-            return True
-
-        async def set_webhook(*args, **kwargs):
-            return True
-
         async def post_init(app):
             # Simply calling app.update_queue.put_nowait(method) in the thread_target doesn't work
             # for some reason (probably threading magic), so we use an event from the thread_target
@@ -2523,9 +2468,7 @@ class TestApplication:
             .post_init(post_init)
             .build()
         )
-        monkeypatch.setattr(app.bot, "get_updates", get_updates)
-        monkeypatch.setattr(app.bot, "set_webhook", set_webhook)
-        monkeypatch.setattr(app.bot, "delete_webhook", delete_webhook)
+        monkeypatch.setattr(app.bot, "get_updates", empty_get_updates)
 
         events = []
         monkeypatch.setattr(
@@ -2543,6 +2486,8 @@ class TestApplication:
             "shutdown",
             call_after(app.shutdown, lambda _: events.append("app.shutdown")),
         )
+        monkeypatch.setattr(app.bot, "set_webhook", return_true)
+        monkeypatch.setattr(app.bot, "delete_webhook", return_true)
 
         def thread_target():
             waited = 0
