@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -40,7 +40,7 @@ class TestContextTypes:
         assert ct.chat_data is float
         assert ct.user_data is bool
 
-        with pytest.raises(ValueError, match="subclass of CallbackContext"):
+        with pytest.raises(TypeError, match="subclass of CallbackContext"):
             ContextTypes(context=bool)
 
     def test_data_assignment(self):
