@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,15 +18,17 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 import asyncio
 import calendar
+import contextlib
 import datetime as dtm
 import logging
 import platform
+import re
 import time
 
 import pytest
 
 from telegram.ext import ApplicationBuilder, CallbackContext, ContextTypes, Defaults, Job, JobQueue
-from tests.auxil.envvars import GITHUB_ACTION, TEST_WITH_OPT_DEPS
+from tests.auxil.envvars import GITHUB_ACTIONS, TEST_WITH_OPT_DEPS
 from tests.auxil.pytest_classes import make_bot
 from tests.auxil.slots import mro_slots
 
@@ -35,16 +37,14 @@ if TEST_WITH_OPT_DEPS:
 
     UTC = pytz.utc
 else:
-    import datetime
-
-    UTC = datetime.timezone.utc
+    UTC = dtm.timezone.utc
 
 
 class CustomContext(CallbackContext):
     pass
 
 
-@pytest.fixture()
+@pytest.fixture
 async def job_queue(app):
     jq = JobQueue()
     jq.set_application(app)
@@ -70,7 +70,7 @@ class TestNoJobQueue:
     not TEST_WITH_OPT_DEPS, reason="Only relevant if the optional dependency is installed"
 )
 @pytest.mark.skipif(
-    bool(GITHUB_ACTION and platform.system() in ["Windows", "Darwin"]),
+    GITHUB_ACTIONS and platform.system() in ["Windows", "Darwin"],
     reason="On Windows & MacOS precise timings are not accurate.",
 )
 @pytest.mark.flaky(10, 1)  # Timings aren't quite perfect
@@ -79,6 +79,13 @@ class TestJobQueue:
     job_time = 0
     received_error = None
 
+    @staticmethod
+    def normalize(datetime: dtm.datetime, timezone: dtm.tzinfo) -> dtm.datetime:
+        with contextlib.suppress(AttributeError):
+            return timezone.normalize(datetime)
+
+        return datetime
+
     async def test_repr(self, app):
         jq = JobQueue()
         jq.set_application(app)
@@ -104,7 +111,7 @@ class TestJobQueue:
         # Unfortunately, we can't really test the executor setting explicitly without relying
         # on protected attributes. However, this should be tested enough implicitly via all the
         # other tests in here
-        assert job_queue.scheduler_configuration["timezone"] is UTC
+        assert job_queue.scheduler_configuration["timezone"] is dtm.timezone.utc
 
         tz_app = ApplicationBuilder().defaults(Defaults(tzinfo=timezone)).token(bot.token).build()
         assert tz_app.job_queue.scheduler_configuration["timezone"] is timezone
@@ -358,6 +365,17 @@ class TestJobQueue:
         scheduled_time = job_queue.jobs()[0].next_t.timestamp()
         assert scheduled_time == pytest.approx(expected_time)
 
+    async def test_time_unit_dt_aware_time(self, job_queue, timezone):
+        # Testing running at a specific tz-aware time today
+        delta, now = 0.5, dtm.datetime.now(timezone)
+        expected_time = now + dtm.timedelta(seconds=delta)
+        when = expected_time.timetz()
+        expected_time = expected_time.timestamp()
+
+        job_queue.run_once(self.job_datetime_tests, when)
+        await asyncio.sleep(0.6)
+        assert self.job_time == pytest.approx(expected_time)
+
     async def test_run_daily(self, job_queue):
         delta, now = 1, dtm.datetime.now(UTC)
         time_of_day = (now + dtm.timedelta(seconds=delta)).time()
@@ -399,7 +417,7 @@ class TestJobQueue:
         if day > next_months_days:
             expected_reschedule_time += dtm.timedelta(next_months_days)
 
-        expected_reschedule_time = timezone.normalize(expected_reschedule_time)
+        expected_reschedule_time = self.normalize(expected_reschedule_time, timezone)
         # Adjust the hour for the special case that between now and next month a DST switch happens
         expected_reschedule_time += dtm.timedelta(
             hours=time_of_day.hour - expected_reschedule_time.hour
@@ -421,7 +439,7 @@ class TestJobQueue:
             calendar.monthrange(now.year, now.month)[1]
         ) - dtm.timedelta(days=now.day)
         # Adjust the hour for the special case that between now & end of month a DST switch happens
-        expected_reschedule_time = timezone.normalize(expected_reschedule_time)
+        expected_reschedule_time = self.normalize(expected_reschedule_time, timezone)
         expected_reschedule_time += dtm.timedelta(
             hours=time_of_day.hour - expected_reschedule_time.hour
         )
@@ -445,19 +463,34 @@ class TestJobQueue:
 
         await jq.stop()
 
-    async def test_get_jobs(self, job_queue):
+    @pytest.mark.parametrize(
+        "pattern", [None, "not", re.compile("not")], ids=["None", "str", "re.Pattern"]
+    )
+    async def test_get_jobs(self, job_queue, pattern):
         callback = self.job_run_once
 
-        job1 = job_queue.run_once(callback, 10, name="name1")
+        job1 = job_queue.run_once(callback, 10, name="is|a|match")
         await asyncio.sleep(0.03)  # To stablize tests on windows
-        job2 = job_queue.run_once(callback, 10, name="name1")
+        job2 = job_queue.run_once(callback, 10, name="is|a|match")
         await asyncio.sleep(0.03)
-        job3 = job_queue.run_once(callback, 10, name="name2")
+        job3 = job_queue.run_once(callback, 10, name="not|is|a|match")
+        await asyncio.sleep(0.03)
+        job4 = job_queue.run_once(callback, 10, name="is|a|match|not")
+        await asyncio.sleep(0.03)
+        job5 = job_queue.run_once(callback, 10, name="something_else")
+        await asyncio.sleep(0.03)
+        # name-less job
+        job6 = job_queue.run_once(callback, 10)
         await asyncio.sleep(0.03)
 
-        assert job_queue.jobs() == (job1, job2, job3)
-        assert job_queue.get_jobs_by_name("name1") == (job1, job2)
-        assert job_queue.get_jobs_by_name("name2") == (job3,)
+        if pattern is None:
+            assert job_queue.jobs(pattern) == (job1, job2, job3, job4, job5, job6)
+        else:
+            assert job_queue.jobs(pattern) == (job3, job4)
+
+        assert job_queue.jobs() == (job1, job2, job3, job4, job5, job6)
+        assert job_queue.get_jobs_by_name("is|a|match") == (job1, job2)
+        assert job_queue.get_jobs_by_name("something_else") == (job5,)
 
     async def test_job_run(self, app):
         job = app.job_queue.run_repeating(self.job_run_once, 0.02)
