@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-import datetime
+import datetime as dtm
 import gzip
 import os
 import pickle
@@ -50,27 +50,27 @@ def _reset_callback_data_cache(cdc_bot):
     cdc_bot.callback_data_cache.clear_callback_queries()
 
 
-@pytest.fixture()
+@pytest.fixture
 def bot_data():
     return {"test1": "test2", "test3": {"test4": "test5"}}
 
 
-@pytest.fixture()
+@pytest.fixture
 def chat_data():
     return {-12345: {"test1": "test2", "test3": {"test4": "test5"}}, -67890: {3: "test4"}}
 
 
-@pytest.fixture()
+@pytest.fixture
 def user_data():
     return {12345: {"test1": "test2", "test3": {"test4": "test5"}}, 67890: {3: "test4"}}
 
 
-@pytest.fixture()
+@pytest.fixture
 def callback_data():
     return [("test1", 1000, {"button1": "test0", "button2": "test1"})], {"test1": "test2"}
 
 
-@pytest.fixture()
+@pytest.fixture
 def conversations():
     return {
         "name1": {(123, 123): 3, (456, 654): 4},
@@ -79,7 +79,7 @@ def conversations():
     }
 
 
-@pytest.fixture()
+@pytest.fixture
 def pickle_persistence():
     return PicklePersistence(
         filepath="pickletest",
@@ -88,7 +88,7 @@ def pickle_persistence():
     )
 
 
-@pytest.fixture()
+@pytest.fixture
 def pickle_persistence_only_bot():
     return PicklePersistence(
         filepath="pickletest",
@@ -98,7 +98,7 @@ def pickle_persistence_only_bot():
     )
 
 
-@pytest.fixture()
+@pytest.fixture
 def pickle_persistence_only_chat():
     return PicklePersistence(
         filepath="pickletest",
@@ -108,7 +108,7 @@ def pickle_persistence_only_chat():
     )
 
 
-@pytest.fixture()
+@pytest.fixture
 def pickle_persistence_only_user():
     return PicklePersistence(
         filepath="pickletest",
@@ -118,7 +118,7 @@ def pickle_persistence_only_user():
     )
 
 
-@pytest.fixture()
+@pytest.fixture
 def pickle_persistence_only_callback():
     return PicklePersistence(
         filepath="pickletest",
@@ -128,7 +128,7 @@ def pickle_persistence_only_callback():
     )
 
 
-@pytest.fixture()
+@pytest.fixture
 def bad_pickle_files():
     for name in [
         "pickletest_user_data",
@@ -142,7 +142,7 @@ def bad_pickle_files():
     return True
 
 
-@pytest.fixture()
+@pytest.fixture
 def invalid_pickle_files():
     for name in [
         "pickletest_user_data",
@@ -159,7 +159,7 @@ def invalid_pickle_files():
     return True
 
 
-@pytest.fixture()
+@pytest.fixture
 def good_pickle_files(user_data, chat_data, bot_data, callback_data, conversations):
     data = {
         "user_data": user_data,
@@ -183,7 +183,7 @@ def good_pickle_files(user_data, chat_data, bot_data, callback_data, conversatio
     return True
 
 
-@pytest.fixture()
+@pytest.fixture
 def pickle_files_wo_bot_data(user_data, chat_data, callback_data, conversations):
     data = {
         "user_data": user_data,
@@ -204,7 +204,7 @@ def pickle_files_wo_bot_data(user_data, chat_data, callback_data, conversations)
     return True
 
 
-@pytest.fixture()
+@pytest.fixture
 def pickle_files_wo_callback_data(user_data, chat_data, bot_data, conversations):
     data = {
         "user_data": user_data,
@@ -225,11 +225,11 @@ def pickle_files_wo_callback_data(user_data, chat_data, bot_data, conversations)
     return True
 
 
-@pytest.fixture()
+@pytest.fixture
 def update(bot):
     user = User(id=321, first_name="test_user", is_bot=False)
     chat = Chat(id=123, type="group")
-    message = Message(1, datetime.datetime.now(), chat, from_user=user, text="Hi there")
+    message = Message(1, dtm.datetime.now(), chat, from_user=user, text="Hi there")
     message.set_bot(bot)
     return Update(0, message=message)
 
@@ -289,7 +289,7 @@ class TestPicklePersistence:
 
     async def test_pickle_behaviour_with_slots(self, pickle_persistence):
         bot_data = await pickle_persistence.get_bot_data()
-        bot_data["message"] = Message(3, datetime.datetime.now(), Chat(2, type="supergroup"))
+        bot_data["message"] = Message(3, dtm.datetime.now(), Chat(2, type="supergroup"))
         await pickle_persistence.update_bot_data(bot_data)
         retrieved = await pickle_persistence.get_bot_data()
         assert retrieved == bot_data
@@ -872,9 +872,12 @@ class TestPicklePersistence:
             "A load persistent id instruction was encountered,\nbut no persistent_load "
             "function was specified."
         )
-        with Path("pickletest_chat_data").open("rb") as f, pytest.raises(
-            pickle.UnpicklingError,
-            match=err_msg if sys.version_info < (3, 12) else err_msg.replace("\n", " "),
+        with (
+            Path("pickletest_chat_data").open("rb") as f,
+            pytest.raises(
+                pickle.UnpicklingError,
+                match=err_msg if sys.version_info < (3, 12) else err_msg.replace("\n", " "),
+            ),
         ):
             pickle.load(f)
 
