@@ -1,5 +1,5 @@
 # python-telegram-bot - a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # by the python-telegram-bot contributors <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 
-import datetime
+import datetime as dtm
 import inspect
 from copy import deepcopy
 
@@ -48,8 +48,9 @@ class ChatBoostDefaults:
     is_unclaimed = False
     chat = Chat(1, "group")
     user = User(1, "user", False)
-    date = to_timestamp(datetime.datetime.utcnow())
+    date = to_timestamp(dtm.datetime.utcnow())
     default_source = ChatBoostSourcePremium(user)
+    prize_star_count = 99
 
 
 @pytest.fixture(scope="module")
@@ -91,6 +92,7 @@ def chat_boost_source_giveaway():
         user=ChatBoostDefaults.user,
         giveaway_message_id=ChatBoostDefaults.giveaway_message_id,
         is_unclaimed=ChatBoostDefaults.is_unclaimed,
+        prize_star_count=ChatBoostDefaults.prize_star_count,
     )
 
 
@@ -107,7 +109,7 @@ def user_chat_boosts(chat_boost):
     )
 
 
-@pytest.fixture()
+@pytest.fixture
 def chat_boost_source(request):
     return request.param()
 
@@ -146,7 +148,7 @@ def iter_args(
         if param.name in ignored:
             continue
         inst_at, json_at = getattr(instance, param.name), getattr(de_json_inst, param.name)
-        if isinstance(json_at, datetime.datetime):  # Convert datetime to int
+        if isinstance(json_at, dtm.datetime):  # Convert dtm to int
             json_at = to_timestamp(json_at)
         if (
             param.default is not inspect.Parameter.empty and include_optional
@@ -170,13 +172,13 @@ class TestChatBoostSourceTypesWithoutRequest:
             assert getattr(inst, attr, "err") != "err", f"got extra slot '{attr}'"
         assert len(mro_slots(inst)) == len(set(mro_slots(inst))), "duplicate slot"
 
-    def test_de_json_required_args(self, bot, chat_boost_source):
+    def test_de_json_required_args(self, offline_bot, chat_boost_source):
         cls = chat_boost_source.__class__
-        assert cls.de_json({}, bot) is None
-        assert ChatBoost.de_json({}, bot) is None
+        assert cls.de_json({}, offline_bot) is None
+        assert ChatBoost.de_json({}, offline_bot) is None
 
         json_dict = make_json_dict(chat_boost_source)
-        const_boost_source = ChatBoostSource.de_json(json_dict, bot)
+        const_boost_source = ChatBoostSource.de_json(json_dict, offline_bot)
         assert const_boost_source.api_kwargs == {}
 
         assert isinstance(const_boost_source, ChatBoostSource)
@@ -186,9 +188,9 @@ class TestChatBoostSourceTypesWithoutRequest:
         ):
             assert chat_mem_type_at == const_chat_mem_at
 
-    def test_de_json_all_args(self, bot, chat_boost_source):
+    def test_de_json_all_args(self, offline_bot, chat_boost_source):
         json_dict = make_json_dict(chat_boost_source, include_optional_args=True)
-        const_boost_source = ChatBoostSource.de_json(json_dict, bot)
+        const_boost_source = ChatBoostSource.de_json(json_dict, offline_bot)
         assert const_boost_source.api_kwargs == {}
 
         assert isinstance(const_boost_source, ChatBoostSource)
@@ -198,19 +200,19 @@ class TestChatBoostSourceTypesWithoutRequest:
         ):
             assert c_mem_type_at == const_c_mem_at
 
-    def test_de_json_invalid_source(self, chat_boost_source, bot):
+    def test_de_json_invalid_source(self, chat_boost_source, offline_bot):
         json_dict = {"source": "invalid"}
-        chat_boost_source = ChatBoostSource.de_json(json_dict, bot)
+        chat_boost_source = ChatBoostSource.de_json(json_dict, offline_bot)
 
         assert type(chat_boost_source) is ChatBoostSource
         assert chat_boost_source.source == "invalid"
 
-    def test_de_json_subclass(self, chat_boost_source, bot):
-        """This makes sure that e.g. ChatBoostSourcePremium(data, bot) never returns a
+    def test_de_json_subclass(self, chat_boost_source, offline_bot):
+        """This makes sure that e.g. ChatBoostSourcePremium(data, offline_bot) never returns a
         ChatBoostSourceGiftCode instance."""
         cls = chat_boost_source.__class__
         json_dict = make_json_dict(chat_boost_source, True)
-        assert type(cls.de_json(json_dict, bot)) is cls
+        assert type(cls.de_json(json_dict, offline_bot)) is cls
 
     def test_to_dict(self, chat_boost_source):
         chat_boost_dict = chat_boost_source.to_dict()
@@ -263,18 +265,18 @@ class TestChatBoostWithoutRequest(ChatBoostDefaults):
             assert getattr(inst, attr, "err") != "err", f"got extra slot '{attr}'"
         assert len(mro_slots(inst)) == len(set(mro_slots(inst))), "duplicate slot"
 
-    def test_de_json(self, bot, chat_boost):
+    def test_de_json(self, offline_bot, chat_boost):
         json_dict = {
             "boost_id": "2",
             "add_date": self.date,
             "expiration_date": self.date,
             "source": self.default_source.to_dict(),
         }
-        cb = ChatBoost.de_json(json_dict, bot)
+        cb = ChatBoost.de_json(json_dict, offline_bot)
 
         assert isinstance(cb, ChatBoost)
-        assert isinstance(cb.add_date, datetime.datetime)
-        assert isinstance(cb.expiration_date, datetime.datetime)
+        assert isinstance(cb.add_date, dtm.datetime)
+        assert isinstance(cb.expiration_date, dtm.datetime)
         assert isinstance(cb.source, ChatBoostSource)
         with cb._unfrozen():
             cb.add_date = to_timestamp(cb.add_date)
@@ -284,7 +286,7 @@ class TestChatBoostWithoutRequest(ChatBoostDefaults):
         for slot in cb.__slots__:
             assert getattr(cb, slot) == getattr(chat_boost, slot), f"attribute {slot} differs"
 
-    def test_de_json_localization(self, bot, raw_bot, tz_bot):
+    def test_de_json_localization(self, offline_bot, raw_bot, tz_bot):
         json_dict = {
             "boost_id": "2",
             "add_date": self.date,
@@ -292,7 +294,7 @@ class TestChatBoostWithoutRequest(ChatBoostDefaults):
             "source": self.default_source.to_dict(),
         }
 
-        cb_bot = ChatBoost.de_json(json_dict, bot)
+        cb_bot = ChatBoost.de_json(json_dict, offline_bot)
         cb_raw = ChatBoost.de_json(json_dict, raw_bot)
         cb_tz = ChatBoost.de_json(json_dict, tz_bot)
 
@@ -347,7 +349,7 @@ class TestChatBoostUpdatedWithoutRequest(ChatBoostDefaults):
             assert getattr(inst, attr, "err") != "err", f"got extra slot '{attr}'"
         assert len(mro_slots(inst)) == len(set(mro_slots(inst))), "duplicate slot"
 
-    def test_de_json(self, bot, chat_boost):
+    def test_de_json(self, offline_bot, chat_boost):
         json_dict = {
             "chat": self.chat.to_dict(),
             "boost": {
@@ -357,7 +359,7 @@ class TestChatBoostUpdatedWithoutRequest(ChatBoostDefaults):
                 "source": self.default_source.to_dict(),
             },
         }
-        cbu = ChatBoostUpdated.de_json(json_dict, bot)
+        cbu = ChatBoostUpdated.de_json(json_dict, offline_bot)
 
         assert isinstance(cbu, ChatBoostUpdated)
         assert cbu.chat == self.chat
@@ -420,14 +422,14 @@ class TestChatBoostRemovedWithoutRequest(ChatBoostDefaults):
             assert getattr(inst, attr, "err") != "err", f"got extra slot '{attr}'"
         assert len(mro_slots(inst)) == len(set(mro_slots(inst))), "duplicate slot"
 
-    def test_de_json(self, bot, chat_boost_removed):
+    def test_de_json(self, offline_bot, chat_boost_removed):
         json_dict = {
             "chat": self.chat.to_dict(),
             "boost_id": "2",
             "remove_date": self.date,
             "source": self.default_source.to_dict(),
         }
-        cbr = ChatBoostRemoved.de_json(json_dict, bot)
+        cbr = ChatBoostRemoved.de_json(json_dict, offline_bot)
 
         assert isinstance(cbr, ChatBoostRemoved)
         assert cbr.chat == self.chat
@@ -435,7 +437,7 @@ class TestChatBoostRemovedWithoutRequest(ChatBoostDefaults):
         assert to_timestamp(cbr.remove_date) == self.date
         assert cbr.source == self.default_source
 
-    def test_de_json_localization(self, bot, raw_bot, tz_bot):
+    def test_de_json_localization(self, offline_bot, raw_bot, tz_bot):
         json_dict = {
             "chat": self.chat.to_dict(),
             "boost_id": "2",
@@ -443,7 +445,7 @@ class TestChatBoostRemovedWithoutRequest(ChatBoostDefaults):
             "source": self.default_source.to_dict(),
         }
 
-        cbr_bot = ChatBoostRemoved.de_json(json_dict, bot)
+        cbr_bot = ChatBoostRemoved.de_json(json_dict, offline_bot)
         cbr_raw = ChatBoostRemoved.de_json(json_dict, raw_bot)
         cbr_tz = ChatBoostRemoved.de_json(json_dict, tz_bot)
 
@@ -498,7 +500,7 @@ class TestUserChatBoostsWithoutRequest(ChatBoostDefaults):
             assert getattr(inst, attr, "err") != "err", f"got extra slot '{attr}'"
         assert len(mro_slots(inst)) == len(set(mro_slots(inst))), "duplicate slot"
 
-    def test_de_json(self, bot, user_chat_boosts):
+    def test_de_json(self, offline_bot, user_chat_boosts):
         json_dict = {
             "boosts": [
                 {
@@ -509,7 +511,7 @@ class TestUserChatBoostsWithoutRequest(ChatBoostDefaults):
                 }
             ]
         }
-        ucb = UserChatBoosts.de_json(json_dict, bot)
+        ucb = UserChatBoosts.de_json(json_dict, offline_bot)
 
         assert isinstance(ucb, UserChatBoosts)
         assert isinstance(ucb.boosts[0], ChatBoost)
@@ -525,7 +527,7 @@ class TestUserChatBoostsWithoutRequest(ChatBoostDefaults):
         assert isinstance(user_chat_boosts_dict["boosts"], list)
         assert user_chat_boosts_dict["boosts"][0] == user_chat_boosts.boosts[0].to_dict()
 
-    async def test_get_user_chat_boosts(self, monkeypatch, bot):
+    async def test_get_user_chat_boosts(self, monkeypatch, offline_bot):
         async def make_assertion(url, request_data: RequestData, *args, **kwargs):
             data = request_data.json_parameters
             chat_id = data["chat_id"] == "3"
@@ -534,9 +536,9 @@ class TestUserChatBoostsWithoutRequest(ChatBoostDefaults):
                 pytest.fail("I got wrong parameters in post")
             return data
 
-        monkeypatch.setattr(bot.request, "post", make_assertion)
+        monkeypatch.setattr(offline_bot.request, "post", make_assertion)
 
-        assert await bot.get_user_chat_boosts("3", 2)
+        assert await offline_bot.get_user_chat_boosts("3", 2)
 
 
 class TestUserChatBoostsWithRequest(ChatBoostDefaults):
