@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -17,7 +17,7 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 import asyncio
-import datetime
+import datetime as dtm
 
 import pytest
 
@@ -32,19 +32,9 @@ from telegram import (
     Sticker,
 )
 from telegram.error import BadRequest
+from tests.auxil.constants import TEST_MSG_TEXT, TEST_TOPIC_ICON_COLOR, TEST_TOPIC_NAME
 from tests.auxil.slots import mro_slots
 
-TEST_MSG_TEXT = "Topics are forever"
-TEST_TOPIC_ICON_COLOR = 0x6FB9F0
-TEST_TOPIC_NAME = "Sad bot true: real stories"
-
-
-@pytest.fixture(scope="module")
-async def emoji_id(bot):
-    emoji_sticker_list = await bot.get_forum_topic_icon_stickers()
-    first_sticker = emoji_sticker_list[0]
-    return first_sticker.custom_emoji_id
-
 
 @pytest.fixture(scope="module")
 async def forum_topic_object(forum_group_id, emoji_id):
@@ -56,23 +46,6 @@ async def forum_topic_object(forum_group_id, emoji_id):
     )
 
 
-@pytest.fixture()
-async def real_topic(bot, emoji_id, forum_group_id):
-    result = await bot.create_forum_topic(
-        chat_id=forum_group_id,
-        name=TEST_TOPIC_NAME,
-        icon_color=TEST_TOPIC_ICON_COLOR,
-        icon_custom_emoji_id=emoji_id,
-    )
-
-    yield result
-
-    result = await bot.delete_forum_topic(
-        chat_id=forum_group_id, message_thread_id=result.message_thread_id
-    )
-    assert result is True, "Topic was not deleted"
-
-
 class TestForumTopicWithoutRequest:
     def test_slot_behaviour(self, forum_topic_object):
         inst = forum_topic_object
@@ -86,8 +59,8 @@ class TestForumTopicWithoutRequest:
         assert forum_topic_object.name == TEST_TOPIC_NAME
         assert forum_topic_object.icon_custom_emoji_id == emoji_id
 
-    def test_de_json(self, bot, emoji_id, forum_group_id):
-        assert ForumTopic.de_json(None, bot=bot) is None
+    def test_de_json(self, offline_bot, emoji_id, forum_group_id):
+        assert ForumTopic.de_json(None, bot=offline_bot) is None
 
         json_dict = {
             "message_thread_id": forum_group_id,
@@ -95,7 +68,7 @@ class TestForumTopicWithoutRequest:
             "icon_color": TEST_TOPIC_ICON_COLOR,
             "icon_custom_emoji_id": emoji_id,
         }
-        topic = ForumTopic.de_json(json_dict, bot)
+        topic = ForumTopic.de_json(json_dict, offline_bot)
         assert topic.api_kwargs == {}
 
         assert topic.message_thread_id == forum_group_id
@@ -270,7 +243,7 @@ class TestForumMethodsWithRequest:
     async def test_edit_general_forum_topic(self, bot, forum_group_id):
         result = await bot.edit_general_forum_topic(
             chat_id=forum_group_id,
-            name=f"GENERAL_{datetime.datetime.now().timestamp()}",
+            name=f"GENERAL_{dtm.datetime.now().timestamp()}",
         )
         assert result is True, "Failed to edit general forum topic"
         # no way of checking the edited name, just the boolean result
@@ -333,11 +306,11 @@ class TestForumTopicCreatedWithoutRequest:
         assert topic_created.icon_color == TEST_TOPIC_ICON_COLOR
         assert topic_created.name == TEST_TOPIC_NAME
 
-    def test_de_json(self, bot):
-        assert ForumTopicCreated.de_json(None, bot=bot) is None
+    def test_de_json(self, offline_bot):
+        assert ForumTopicCreated.de_json(None, bot=offline_bot) is None
 
         json_dict = {"icon_color": TEST_TOPIC_ICON_COLOR, "name": TEST_TOPIC_NAME}
-        action = ForumTopicCreated.de_json(json_dict, bot)
+        action = ForumTopicCreated.de_json(json_dict, offline_bot)
         assert action.api_kwargs == {}
 
         assert action.icon_color == TEST_TOPIC_ICON_COLOR
