@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -29,19 +29,19 @@ from tests.auxil.slots import mro_slots
 @pytest.fixture(scope="class")
 def maybe_inaccessible_message():
     return MaybeInaccessibleMessage(
-        TestMaybeInaccessibleMessageBase.chat,
-        TestMaybeInaccessibleMessageBase.message_id,
-        TestMaybeInaccessibleMessageBase.date,
+        MaybeInaccessibleMessageTestBase.chat,
+        MaybeInaccessibleMessageTestBase.message_id,
+        MaybeInaccessibleMessageTestBase.date,
     )
 
 
-class TestMaybeInaccessibleMessageBase:
+class MaybeInaccessibleMessageTestBase:
     chat = Chat(1, "title")
     message_id = 123
     date = dtm.datetime.now(dtm.timezone.utc).replace(microsecond=0)
 
 
-class TestMaybeInaccessibleMessageWithoutRequest(TestMaybeInaccessibleMessageBase):
+class TestMaybeInaccessibleMessageWithoutRequest(MaybeInaccessibleMessageTestBase):
     def test_slot_behaviour(self, maybe_inaccessible_message):
         for attr in maybe_inaccessible_message.__slots__:
             assert (
@@ -59,20 +59,20 @@ class TestMaybeInaccessibleMessageWithoutRequest(TestMaybeInaccessibleMessageBas
         assert maybe_inaccessible_message_dict["message_id"] == self.message_id
         assert maybe_inaccessible_message_dict["date"] == to_timestamp(self.date)
 
-    def test_de_json(self, bot):
+    def test_de_json(self, offline_bot):
         json_dict = {
             "chat": self.chat.to_dict(),
             "message_id": self.message_id,
             "date": to_timestamp(self.date),
         }
-        maybe_inaccessible_message = MaybeInaccessibleMessage.de_json(json_dict, bot)
+        maybe_inaccessible_message = MaybeInaccessibleMessage.de_json(json_dict, offline_bot)
         assert maybe_inaccessible_message.api_kwargs == {}
 
         assert maybe_inaccessible_message.chat == self.chat
         assert maybe_inaccessible_message.message_id == self.message_id
         assert maybe_inaccessible_message.date == self.date
 
-    def test_de_json_localization(self, tz_bot, bot, raw_bot):
+    def test_de_json_localization(self, tz_bot, offline_bot, raw_bot):
         json_dict = {
             "chat": self.chat.to_dict(),
             "message_id": self.message_id,
@@ -80,7 +80,7 @@ class TestMaybeInaccessibleMessageWithoutRequest(TestMaybeInaccessibleMessageBas
         }
 
         maybe_inaccessible_message_raw = MaybeInaccessibleMessage.de_json(json_dict, raw_bot)
-        maybe_inaccessible_message_bot = MaybeInaccessibleMessage.de_json(json_dict, bot)
+        maybe_inaccessible_message_bot = MaybeInaccessibleMessage.de_json(json_dict, offline_bot)
         maybe_inaccessible_message_bot_tz = MaybeInaccessibleMessage.de_json(json_dict, tz_bot)
 
         # comparing utcoffsets because comparing timezones is unpredicatable
@@ -95,14 +95,14 @@ class TestMaybeInaccessibleMessageWithoutRequest(TestMaybeInaccessibleMessageBas
         assert maybe_inaccessible_message_bot.date.tzinfo == UTC
         assert maybe_inaccessible_message_bot_tz_offset == tz_bot_offset
 
-    def test_de_json_zero_date(self, bot):
+    def test_de_json_zero_date(self, offline_bot):
         json_dict = {
             "chat": self.chat.to_dict(),
             "message_id": self.message_id,
             "date": 0,
         }
 
-        maybe_inaccessible_message = MaybeInaccessibleMessage.de_json(json_dict, bot)
+        maybe_inaccessible_message = MaybeInaccessibleMessage.de_json(json_dict, offline_bot)
         assert maybe_inaccessible_message.date == ZERO_DATE
         assert maybe_inaccessible_message.date is ZERO_DATE
 
