@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -24,28 +24,28 @@ from tests.auxil.slots import mro_slots
 
 @pytest.fixture(scope="module")
 def story():
-    return Story(TestStoryBase.chat, TestStoryBase.id)
+    return Story(StoryTestBase.chat, StoryTestBase.id)
 
 
-class TestStoryBase:
+class StoryTestBase:
     chat = Chat(1, "")
     id = 0
 
 
-class TestStoryWithoutRequest(TestStoryBase):
+class TestStoryWithoutRequest(StoryTestBase):
     def test_slot_behaviour(self, story):
         for attr in story.__slots__:
             assert getattr(story, attr, "err") != "err", f"got extra slot '{attr}'"
         assert len(mro_slots(story)) == len(set(mro_slots(story))), "duplicate slot"
 
-    def test_de_json(self, bot):
+    def test_de_json(self, offline_bot):
         json_dict = {"chat": self.chat.to_dict(), "id": self.id}
-        story = Story.de_json(json_dict, bot)
+        story = Story.de_json(json_dict, offline_bot)
         assert story.api_kwargs == {}
         assert story.chat == self.chat
         assert story.id == self.id
         assert isinstance(story, Story)
-        assert Story.de_json(None, bot) is None
+        assert Story.de_json(None, offline_bot) is None
 
     def test_to_dict(self, story):
         story_dict = story.to_dict()
